@@ -185,10 +185,11 @@ char *finish_add_bootstrap(int replicates)
 	f3 = recur_write_tree(r3, r3p, arbre3, arbre3 + taille, mainbranches);
 	if(f3 == NULL) return NULL;
 	*(f3 + 1) = 0;
-	arbre = (char *)malloc( f1 - arbre1 + f2 - arbre2 + f3 - arbre3 + 100);
-	if(has_br_length) sprintf(arbre, "(%s:%.5f,%s:%.5f,%s%s:%.5f);", arbre1, l1, arbre2, l2, arbre3, 
+        int larbre = f1 - arbre1 + f2 - arbre2 + f3 - arbre3 + 100;
+	arbre = (char *)malloc(larbre);
+	if(has_br_length) snprintf(arbre, larbre, "(%s:%.5f,%s:%.5f,%s%s:%.5f);", arbre1, l1, arbre2, l2, arbre3,
 			bootstrap != NULL ? bootstrap : "", l3);
-	else 	sprintf(arbre, "(%s,%s,%s%s);", arbre1, arbre2, arbre3, bootstrap != NULL ? bootstrap : "");
+	else 	snprintf(arbre, larbre, "(%s,%s,%s%s);", arbre1, arbre2, arbre3, bootstrap != NULL ? bootstrap : "");
 
 	free(arbre1); free(arbre2); free(arbre3);
 	free_arbre(racine, NULL);
@@ -486,7 +487,7 @@ else	{
 	if(arbre==NULL) return NULL;
 	if(has_br_length) {
 		if(arbre+10>=finarbre) return NULL;
-		sprintf(++arbre,":%.5f",lg);
+		snprintf(++arbre, 20,":%.5f",lg);
 		while(*arbre!=0) arbre++;
 		}
 	else arbre++;
@@ -495,7 +496,7 @@ else	{
 	if(arbre==NULL) return NULL;
 	if(has_br_length) {
 		if(arbre+10>=finarbre) return NULL;
-		sprintf(++arbre,":%.5f",ld);
+		snprintf(++arbre, 20,":%.5f",ld);
 		while(*arbre!=0) arbre++;
 		}
 	else arbre++;
@@ -737,7 +738,7 @@ else p = nan;
 for(num = 0; num < totbranches; num++) {
 	br = branches + num;
 	if(br->br_label != NULL) free(br->br_label);
-	if (count) sprintf(text, "%d", (int)(br->count * 100. / count + 0.5) );
+	if (count) snprintf(text, 20, "%d", (int)(br->count * 100. / count + 0.5) );
 	br->br_label = strdup(p);
 	}
 }
@@ -911,8 +912,9 @@ char *compute_consensus_tree(char **seqnames, int **rows, int branch_count)
       bit0(column_mask, i+1); // remove row (=tree internal branch) i from list of remaining rows
       restbranches--; // one branch less to process
       // build growing tree string containing leave j
-      newtree = (char*)malloc(strlen(treeparts[j]) + 2);
-      sprintf(newtree, "(%s", treeparts[j]);
+      int ltree = strlen(treeparts[j]) + 2;
+      newtree = (char*)malloc(ltree);
+      snprintf(newtree, ltree, "(%s", treeparts[j]);
       j1 = j+1;
       while ( (j1 = irbit(row_tmp, j1, notu)) != 0) { // add names of all found leaves
 	k = j1-1;
@@ -940,7 +942,7 @@ char *compute_consensus_tree(char **seqnames, int **rows, int branch_count)
   p = newtree;
   for (i = 0; i < notu; i++) {
     if (!treeparts[i]) continue;
-    sprintf(p, ",%s", treeparts[i]);
+    snprintf(p, strlen(treeparts[i])+2, ",%s", treeparts[i]);
     p += strlen(p);
     free(treeparts[i]);
     treeparts[i] = NULL;
