@@ -6,7 +6,7 @@
 #ifdef unix
 #include <unistd.h>
 #endif
-#ifdef WIN32
+#ifdef _WIN32
 #define tempnam _tempnam
 #endif
 
@@ -104,7 +104,7 @@ for(num = 0; num < tot_seqs; num++) {
 		if( sequence[num][pos] == 0 ) break;
 		if( sequence[num][pos] == '-' || sequence[num][pos] == '!') continue;
 		if(empty_seq) {
-			sprintf(lname, "%d_%.10s", ++current, seqname[num]);
+			snprintf(lname, sizeof(lname), "%d_%.10s", ++current, seqname[num]);
 			fprintf(out, ">%.10s\n", lname);
  			if(ferror(out)) goto fin;
 			empty_seq = FALSE;
@@ -138,7 +138,7 @@ return retval;
 }
 
 
-#if ! ( defined(WIN32)  ||  defined(__APPLE__) )
+#if ! ( defined(_WIN32)  ||  defined(FLTK_COCOA_PLATFORM) )
 void align_listener(int fd, void *data)
 {
 char line[100];
@@ -180,7 +180,7 @@ else	{
 p = create_tmp_filename();
 if(p == NULL) return;
 strcpy(base_fname, p);
-sprintf(fname, "%s.pir", base_fname);
+snprintf(fname, PATH_MAX, "%s.pir", base_fname);
 /* allonger les seqs plus courtes que la region traitee sans compter comme modif alignment*/
 int old_modif_but_not_saved = view->modif_but_not_saved;
 for(l = 0; l < view->tot_seqs; l++) {
@@ -221,7 +221,7 @@ if(status) {
 	return;
 	}
   if (no_gui) {
-#ifdef WIN32
+#ifdef _WIN32
 #define system(a) mysystem(a)
     extern int mysystem(const char *command);
 #endif
@@ -229,7 +229,7 @@ if(status) {
     }
   else status = run_external_prog_in_pseudoterm(commande, NULL, "alignment");
 free(commande);
-sprintf(fname, "%s.out", base_fname);
+snprintf(fname, PATH_MAX, "%s.out", base_fname);
 if( status == 0 ) {
 	in = fopen(fname, "r");
         if(in != NULL) {
@@ -317,8 +317,9 @@ if( num != total) {
 	if(num > 0) free(seq); 
   static char *message = NULL;
   if (message) free(message);
-  message = (char*)malloc(strlen(fname) + 100);
-  sprintf(message, "Error in file of aligned sequences:\n%s", fname);
+  int lmessage = strlen(fname) + 100;
+  message = (char*)malloc(lmessage);
+  snprintf(message, lmessage, "Error in file of aligned sequences:\n%s", fname);
   *err_message = message;
 	return TRUE; 
 	}
@@ -585,11 +586,11 @@ char *algo_name;
 char local[400], tmp[400], *p, *optargs;
 int status;
 
-sprintf(tmp, "msa_name_%d", view->alignment_algorithm +  1);
+snprintf(tmp, sizeof(tmp), "msa_name_%d", view->alignment_algorithm +  1);
 algo_name = strdup( get_res_value(tmp, NULL) );
 	
 /* check if program present */
-#if defined(WIN32)
+#if defined(_WIN32)
 char w32path[400];
 strcpy(tmp, algo_name);
 if(strchr(algo_name, '\\') == NULL && strchr(algo_name, '.') == NULL) strcat(tmp, ".exe");
@@ -606,7 +607,7 @@ if(status) {
 	return NULL;
 	}
 	
-sprintf(tmp, "msa_args_%d", view->alignment_algorithm +  1);
+snprintf(tmp, sizeof(tmp), "msa_args_%d", view->alignment_algorithm +  1);
 strcpy(local, get_res_value(tmp, NULL));
 
 /* add user-entered options to command */
@@ -615,10 +616,10 @@ optargs = get_algo_opts(view->alignment_algorithm, NULL);
 status = view->menu_align[clustalopt + MAX_MSA_ALGOS ].flags;
 if(optargs != NULL && (status & FL_MENU_VALUE) ) {
 	if (strchr(local, '>') != NULL) {
-	  sprintf(tmp, "%s %s", optargs, local);
+	  snprintf(tmp, sizeof(tmp), "%s %s", optargs, local);
 	  }
 	else {
-		sprintf(tmp, "%s %s", local, optargs);
+		snprintf(tmp, sizeof(tmp), "%s %s", local, optargs);
 		}
 	strcpy(local, tmp);
 	}
@@ -643,18 +644,20 @@ while((p = strstr(local, "%f")) != NULL) {
   *q = s;
   s = *r;
   *r = 0;
-  sprintf(tmp + strlen(tmp), "\"%s%s%s\"", q, base_fname, p+2);
+  snprintf(tmp + strlen(tmp), sizeof(tmp)-strlen(tmp), "\"%s%s%s\"", q, base_fname, p+2);
   *r = s;
   if (*r) strcat(tmp, r);
   strcpy(local, tmp);
   }
 /* build complete command string */
-#if defined(WIN32)
-	command = (char *)malloc(strlen(w32path) + strlen(local) + 30);
-	sprintf(command, "\"%s\" %s ", w32path, local);
+#if defined(_WIN32)
+        int lcommand = strlen(w32path) + strlen(local) + 30;
+	command = (char *)malloc(lcommand);
+	snprintf(command, lcommand, "\"%s\" %s ", w32path, local);
 #else
-	command = (char *)malloc(strlen(get_full_path(algo_name)) + strlen(local) + 10);
-	sprintf(command, "\"%s\" %s ", get_full_path(algo_name), local);
+  int lcommand = strlen(get_full_path(algo_name)) + strlen(local) + 10;
+	command = (char *)malloc(lcommand);
+	snprintf(command, lcommand, "\"%s\" %s ", get_full_path(algo_name), local);
 #endif
 free(algo_name);
 return command;
@@ -729,11 +732,11 @@ void cre_align_menu(SEA_VIEW *view)
     attr = FL_MENU_RADIO; 
     alignitems[clustalopt + elt - 1].callback(align_opt_callback, elt - 1);
     if (elt <= view->count_msa_algos) {
-      sprintf(msa_name, "msa_name_%d", elt);
+      snprintf(msa_name, sizeof(msa_name), "msa_name_%d", elt);
       name = get_res_value(msa_name, NULL);
       alignitems[clustalopt + elt - 1].label(strdup(name));
       if (elt == view->count_msa_algos) attr |= FL_MENU_DIVIDER;
-#ifndef WIN32
+#ifndef _WIN32
       if (get_full_path(name) == NULL) {
 	attr |= FL_MENU_INACTIVE;
 	} 
@@ -747,8 +750,9 @@ void cre_align_menu(SEA_VIEW *view)
     }
   (alignitems + clustalopt + view->alignment_algorithm)->set();
   name = get_algo_opts(view->alignment_algorithm, NULL);
-  char *options = new char[100 + (name ? strlen(name) : 0) ];
-  sprintf(options, "%s", name == NULL ? "<none>" : name);
+  int loptions = 100 + (name ? strlen(name) : 0);
+  char *options = new char[loptions];
+  snprintf(options, loptions, "%s", name == NULL ? "<none>" : name);
   attr = FL_MENU_TOGGLE;
   if(name == NULL) attr |= FL_MENU_INACTIVE;
   alignitems[clustalopt + MAX_MSA_ALGOS].label(strdup(options));
@@ -780,7 +784,7 @@ for(x = 0; x < view->count_msa_algos; x++) {
 	if(strcmp(name, (menu_align + clustalopt + x)->label() ) == 0) doit = FALSE;
 	}
 if(doit) doit = (name != NULL && args != NULL && strlen(name) >= 2 && strlen(args) >= 2);
-#ifdef WIN32
+#ifdef _WIN32
 strcpy(tmp, name);
 if(strchr(tmp, '\\') == NULL && strchr(tmp, '.') == NULL) strcat(tmp, ".exe");
 if(get_full_path(tmp) == NULL) 
@@ -801,11 +805,11 @@ if(doit) {
 	set_algo_option_item(NULL, menu_align, clustalopt + MAX_MSA_ALGOS, FALSE);
 	(menu_align + clustalopt + MAX_MSA_ALGOS + 3)->activate();
 	++(view->count_msa_algos);
-	sprintf(tmp, "%d", view->count_msa_algos);
+	snprintf(tmp, sizeof(tmp), "%d", view->count_msa_algos);
 	set_res_value("msa_algo_count", tmp);
-	sprintf(tmp, "msa_name_%d", view->count_msa_algos);
+	snprintf(tmp, sizeof(tmp), "msa_name_%d", view->count_msa_algos);
 	set_res_value(tmp, name);
-	sprintf(tmp, "msa_args_%d", view->count_msa_algos);
+	snprintf(tmp, sizeof(tmp), "msa_args_%d", view->count_msa_algos);
 	set_res_value(tmp, args);
 	save_resources();
   if (view->count_msa_algos == MAX_MSA_ALGOS) (menu_align + clustalopt + MAX_MSA_ALGOS + 2)->deactivate();
@@ -822,7 +826,7 @@ Fl_Menu_Item *menu_align = (Fl_Menu_Item*)view->menu_align;
 char msa_name[20], *name;
 int num, status;
 
-sprintf(msa_name, "msa_name_%d", view->alignment_algorithm + 1);
+snprintf(msa_name, sizeof(msa_name), "msa_name_%d", view->alignment_algorithm + 1);
 name = get_res_value(msa_name, NULL);
 if(name == NULL) return;
 int rep = fl_choice("Delete alignment method  '%s'  ?", "Keep", "Delete", NULL, name);
@@ -832,14 +836,14 @@ for(num = view->alignment_algorithm + 1; num <= view->count_msa_algos - 1; num++
 	name = (char *)(menu_align + clustalopt + num)->label();
 	(menu_align + clustalopt + num - 1)->label(name);
 	
-	sprintf(msa_name, "msa_name_%d", num + 1);
+	snprintf(msa_name, sizeof(msa_name), "msa_name_%d", num + 1);
 	name = get_res_value(msa_name, NULL);
-	sprintf(msa_name, "msa_name_%d", num);
+	snprintf(msa_name, sizeof(msa_name), "msa_name_%d", num);
 	set_res_value(msa_name, name);
 
-	sprintf(msa_name, "msa_args_%d", num + 1);
+	snprintf(msa_name, sizeof(msa_name), "msa_args_%d", num + 1);
 	name = get_res_value(msa_name, NULL);
-	sprintf(msa_name, "msa_args_%d", num);
+	snprintf(msa_name, sizeof(msa_name), "msa_args_%d", num);
 	set_res_value(msa_name, name);
 	
 	name = get_opt_resname(num);
@@ -854,20 +858,20 @@ for(num = view->alignment_algorithm + 1; num <= view->count_msa_algos - 1; num++
 	}
   menu_align[clustalopt + view->count_msa_algos - 1].flags = FL_MENU_INVISIBLE;
   menu_align[clustalopt + view->count_msa_algos - 1].label("");
-sprintf(msa_name, "msa_name_%d", view->count_msa_algos);
+snprintf(msa_name, sizeof(msa_name), "msa_name_%d", view->count_msa_algos);
 delete_res_value(msa_name);
-sprintf(msa_name, "msa_args_%d", view->count_msa_algos);
+snprintf(msa_name, sizeof(msa_name), "msa_args_%d", view->count_msa_algos);
 delete_res_value(msa_name);
 name = get_opt_resname(view->count_msa_algos - 1);
 delete_res_value(name);
 --(view->count_msa_algos);
-sprintf(msa_name, "%d", view->count_msa_algos);
+snprintf(msa_name, sizeof(msa_name), "%d", view->count_msa_algos);
 set_res_value("msa_algo_count", msa_name);
 status = menu_align[ clustalopt + view->count_msa_algos - 1 ].flags;
 menu_align[ clustalopt + view->count_msa_algos - 1 ].flags = status | FL_MENU_DIVIDER ;
 num = int_res_value("alignment", 0);
 view->alignment_algorithm = (num < view->count_msa_algos ? num : 0);
-  sprintf(msa_name, "%d", view->alignment_algorithm);
+  snprintf(msa_name, sizeof(msa_name), "%d", view->alignment_algorithm);
   set_res_value("alignment", msa_name);
 (menu_align + clustalopt + view->alignment_algorithm)->setonly();
 name = get_algo_opts(view->alignment_algorithm, NULL);
@@ -884,13 +888,17 @@ void choose_align_callback(Fl_Widget *ob, void *data)
 Fl_Native_File_Chooser *chooser = new Fl_Native_File_Chooser();
 chooser->type(Fl_Native_File_Chooser::BROWSE_FILE);   // let user browse a single file
 chooser->title("Select external alignment program");                        
-#if defined(WIN32)
+#if defined(_WIN32)
 	chooser->filter("*.exe");                 
 #endif
 char *filename = run_and_close_native_file_chooser(chooser);
 if(filename == NULL) return;
 ((Fl_Input*)data)->value(filename);
-((Fl_Input*)data)->position(strlen(filename));
+#if 10000*FL_MAJOR_VERSION + 100*FL_MINOR_VERSION >= 10400
+  ((Fl_Input*)data)->insert_position(strlen(filename));
+#else
+  ((Fl_Input*)data)->position(strlen(filename));
+#endif
 }
 
 
@@ -905,7 +913,7 @@ if(w == NULL) {
 	w = new Fl_Window(530, 100, "alignment method creation");
 	name = new Fl_Input(85, 10, 250, 20, "Name");
 	name->tooltip("Enter name of program from PATH"
-#ifdef WIN32
+#ifdef _WIN32
 	" or seaview's directory"
 #endif
 	" or select program using button at right");
@@ -922,8 +930,8 @@ if(w == NULL) {
 	Fl_Button *b2 = new Fl_Button(10, 70, 50, 20, "Cancel");
 	b2->callback(add_align_callback, NULL);
 	}
-name->value(NULL);
-args->value(NULL);
+name->value("");
+args->value("");
 name->take_focus();
 w->user_data(view);
 w->show();
@@ -941,7 +949,7 @@ char *opts, *optresname;
 char resname[20], *name;
 int clustalopt = ALIGN_OPTIONS + 1;
 
-sprintf(resname, "msa_name_%d", view->alignment_algorithm + 1);
+snprintf(resname, sizeof(resname), "msa_name_%d", view->alignment_algorithm + 1);
 name = get_res_value(resname, NULL);
 opts = get_algo_opts(view->alignment_algorithm, &optresname);
 opts = (char *)fl_input("Optional arguments for method   '%s'\n"
@@ -970,7 +978,7 @@ if(reponse >= 0 && reponse <  view->count_msa_algos) {
 	if(view->alignment_algorithm >= 2) ((Fl_Menu_Item *)view->menu_align + clustalopt + MAX_MSA_ALGOS + 3)->activate();
 	else ((Fl_Menu_Item *)view->menu_align + clustalopt + MAX_MSA_ALGOS + 3)->deactivate();
   char tmp[5];
-  sprintf(tmp, "%d", reponse);
+  snprintf(tmp, 5, "%d", reponse);
   set_res_value("alignment", tmp);
   save_resources();
 	}
@@ -988,7 +996,7 @@ return get_res_value(resname, NULL);
 char *get_opt_resname(int algonum)
 {
 static char resname[20];
-sprintf(resname, "msa_opt_args_%d", algonum + 1);
+snprintf(resname, 20, "msa_opt_args_%d", algonum + 1);
 return resname;
 }
 
@@ -1115,7 +1123,7 @@ void profile_align(SEA_VIEW *view)
 	p = create_tmp_filename();
 	if(p == NULL) return;
 	strcpy(base_fname, p);
-	sprintf(fname1, "%s_1.fasta", base_fname);
+	snprintf(fname1, sizeof(fname1), "%s_1.fasta", base_fname);
 	total = 0;
 	for(num = 0; num < view->tot_seqs; num++) {
 		if(view->sel_seqs[num]) total++;
@@ -1136,7 +1144,7 @@ void profile_align(SEA_VIEW *view)
 		return;
 		}
 	replace_stars(fname1);
-	sprintf(fname2, "%s_2.fasta", base_fname);
+	snprintf(fname2, sizeof(fname2), "%s_2.fasta", base_fname);
 	if ( check_alignment_characters(view, view->sel_seqs) ) return;
 	if(profile_to_profile) {
 		status = save_fasta_file_no_gaponly(fname2, view->sequence, view->tot_seqs, view->each_length, 
@@ -1152,7 +1160,7 @@ void profile_align(SEA_VIEW *view)
 		}
 	p = get_res_value( profile_algo == profile_clustalo ? "msa_name_1" : "msa_name_2", NULL);
 	strcpy(tmp, p);
-#ifdef WIN32
+#ifdef _WIN32
 	strcat(tmp, ".exe");
 #endif
 	p = get_full_path(tmp);
@@ -1163,7 +1171,7 @@ void profile_align(SEA_VIEW *view)
 	else {
 		command = new char[1000];
 		if(profile_algo == profile_clustalo) {
-			sprintf(command, 
+			snprintf(command, 1000,
 				"\"%s\" -v \"--profile1=%s\" %s%s\"  --outfmt=fasta -o \"%s.aligned\" -t %s", 
 				p, fname1, 
 				profile_to_profile ? "\"--profile2=" : "-i \"",
@@ -1172,14 +1180,14 @@ void profile_align(SEA_VIEW *view)
 				view->protein ? "protein" : "dna" );
 			}
 		else { // muscle
-			sprintf(command, 
+			snprintf(command, 1000,
 				"\"%s\" -profile -in1 \"%s\" -in2 \"%s\" -out \"%s.aligned\" ", 
 				p, fname1, fname2, base_fname );
 			}
 		status = run_external_prog_in_pseudoterm(command, NULL, "profile alignment");
 		delete[] command;
 		}
-	sprintf(fname1, "%s.aligned", base_fname);
+	snprintf(fname1, sizeof(fname1), "%s.aligned", base_fname);
 	/* lecture de l'alignement multiple */
 	if( status == 0 ) {
 		num = read_fasta_align(fname1, &seq, &seqname, &comments, &pheader, &err_message, FALSE);
@@ -1342,7 +1350,7 @@ int save_fasta_file_no_gaponly(char *fname, char **sequence, int tot_seqs, int *
 		if(sel_seqs[num]) l = FL_max(l, each_length[num]);
 		seqname[num] = (char *)malloc(10);
 		if(seqname[num] == NULL) return 1;
-		sprintf(seqname[num], "S_%d", num);
+		snprintf(seqname[num], 10, "S_%d", num);
 		}
 	for(pos = 0; pos < l; pos++) {
 		for(num = 0; num < tot_seqs; num++) {
@@ -1504,7 +1512,8 @@ int command_line_align(int argc, char **argv)
   item->clear() ;
   if ( (p = argname(argc, argv, "-align_extra_args")) != NULL) {
     item->set();
-    sprintf(opt_name, "msa_opt_args_%d", view->alignment_algorithm + 1);
+    snprintf(opt_name, sizeof(opt_name), "msa_opt_args_%d",
+             view->alignment_algorithm + 1);
     old_opt_args = strdup(get_res_value(opt_name, ""));
     set_res_value(opt_name, p);
     }
