@@ -77,13 +77,11 @@ void   load_tree(long treei);
 /* function prototypes */
 
 
-static Char infilename[FNMLNGTH], outfilename[FNMLNGTH], intreename[FNMLNGTH], *outtreename,
-     weightfilename[FNMLNGTH];
+static Char   *outtreename;
 char basechar[32]="ACMGRSVTWYHKDBNO???????????????";
 static node *root;
 static long chars, col, msets, ith, njumble, jumb, maxtrees;
 /*   chars = number of sites in actual sequences */
-static long inseed, inseed0;
 static double threshold;
 static boolean jumble, usertree, thresh, weights, thorough, rearrfirst,
           trout, progress, stepbox, ancseq, mulsets, justwts, firstset, mulf,
@@ -109,7 +107,6 @@ baseptr nothing;
 static gbases *garbage;
 static node *temp, *temp1, *temp2, *tempsum, *temprm, *tempadd, *tempf, *tmp, *tmp1,
        *tmp2, *tmp3, *tmprm, *tmpadd;
-static boolean *names;
 node *grbg;
 static char *progname;
 
@@ -210,7 +207,7 @@ static void getoptions(int arg_maxtrees, dnapars_S_option s_option)
     printf("  6       Write out trees onto tree file?  %s\n",
            trout ? "Yes" : "No");
     printf("\n  Y to accept these or type the letter for one to change\n");
-#ifdef WIN32
+#ifdef _WIN32
     phyFillScreenColor();
 #endif
     fflush(stdout);
@@ -259,7 +256,7 @@ static void getoptions(int arg_maxtrees, dnapars_S_option s_option)
           loopcount2 = 0;
           do {
             printf(" (type D or W)\n");
-#ifdef WIN32
+#ifdef _WIN32
             phyFillScreenColor();
 #endif
             fflush(stdout);
@@ -293,7 +290,7 @@ static void getoptions(int arg_maxtrees, dnapars_S_option s_option)
           loopcount2 = 0;
           do {
             printf(" (type Y or N)\n");
-#ifdef WIN32
+#ifdef _WIN32
             phyFillScreenColor();
 #endif
             fflush(stdout);
@@ -312,7 +309,7 @@ static void getoptions(int arg_maxtrees, dnapars_S_option s_option)
         loopcount2 = 0;
         do {
           printf("type the number of trees to save\n");
-#ifdef WIN32
+#ifdef _WIN32
           phyFillScreenColor();
 #endif
           fflush(stdout);
@@ -1466,7 +1463,7 @@ static void maketree(char *toevaluate)
       }
     }
   } else {
-    /* Open in binary: ftell() is broken for UNIX line-endings under WIN32 */
+    /* Open in binary: ftell() is broken for UNIX line-endings under _WIN32 */
     //openfile(&intree,INTREE,"input tree", "rb",progname,intreename);
     //numtrees = countsemic(&intree);
     numtrees = 1;
