@@ -3,9 +3,9 @@
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
-#if defined(WIN32)
+#if defined(_WIN32)
 #include <Windows.h>
-#elif defined(unix) || defined(__APPLE__)
+#elif defined(unix) || defined(FLTK_COCOA_PLATFORM)
 #define unixlike
 #include <termios.h>
 #endif
@@ -835,7 +835,7 @@ char *p, c;
 #ifdef unixlike
 struct termios initialrsettings, newrsettings;
 int err;
-#elif defined(WIN32)
+#elif defined(_WIN32)
 DWORD mode, savemode, lu;
 HANDLE hconsole;
 int err;
@@ -849,7 +849,7 @@ if(err == 0) {
 	newrsettings.c_lflag &= ~ICANON;
 	tcsetattr( fileno(stdin), TCSAFLUSH, &newrsettings );
 	}
-#elif defined(WIN32)
+#elif defined(_WIN32)
 hconsole = GetStdHandle(STD_INPUT_HANDLE);
 err = GetConsoleMode(hconsole, &savemode);
 if(err != 0) {
@@ -862,7 +862,7 @@ if(err != 0) {
 #endif
 p = password;
 do {
-#ifdef WIN32
+#ifdef _WIN32
 	ReadConsole(hconsole, &c, 1, &lu, NULL);
 #else
 	c = getchar();
@@ -886,7 +886,7 @@ if(err == 0) {
 	tcsetattr( fileno(stdin), TCSANOW, &initialrsettings );
 	putchar('\n');
 	}
-#elif defined(WIN32)
+#elif defined(_WIN32)
 if(err != 0) {
 	SetConsoleMode(hconsole, savemode);
 	putchar('\n');
