@@ -35,7 +35,7 @@ extern double next_random(void);
 
 #include "phylip.h"
 
-#ifdef WIN32
+#ifdef _WIN32
 #include <windows.h>
 /* for console code (clear screen, text color settings) */
 CONSOLE_SCREEN_BUFFER_INFO      savecsbi;
@@ -47,7 +47,7 @@ void phySaveConsoleAttributes();
 void phySetConsoleAttributes();
 void phyRestoreConsoleAttributes();
 void phyFillScreenColor();
-#endif /* WIN32 */
+#endif /* _WIN32 */
 
 #ifndef OLDC
 static void crash_handler(int signum);
@@ -109,7 +109,7 @@ static void crash_handler(int sig_num)
   puts("       a full description of the problem, and with the input data file.");
   puts("       (which should be in the body of the message, not as an Attachment).");
 
-#ifdef WIN32
+#ifdef _WIN32
   phyRestoreConsoleAttributes();
 #endif
   abort();
@@ -148,11 +148,11 @@ void init(int argc, char** argv)
   /* Clear the screen */
   cleerhome();
 
-#ifdef WIN32
+#ifdef _WIN32
   /* Perform DOS console configuration */
   phySetConsoleAttributes();
   phyClearScreen();
-#endif /* WIN32 */
+#endif /* _WIN32 */
 
 }
 
@@ -300,7 +300,7 @@ void openfile(FILE **fp,const char *filename,const char *filedesc,
       loopcount2 = 0;
       do {
         printf("     (please type R, A, F, or Q) \n");
-#ifdef WIN32
+#ifdef _WIN32
         phyFillScreenColor();
 #endif
         fflush(stdout);
@@ -378,7 +378,7 @@ void openfile(FILE **fp,const char *filename,const char *filedesc,
 
 void cleerhome()
 { /* home cursor and clear screen, if possible */
-#ifdef WIN32
+#ifdef _WIN32
   if(ibmpc || ansi){
     phyClearScreen();
   } else {
@@ -458,7 +458,7 @@ double normrand(longer seed)
 long readlong(const char *prompt)
 { /* read a long */
   long res, loopcount;
-  char string[100];
+  char string[FNMLNGTH];
 
   loopcount = 0;
   do {
@@ -593,7 +593,7 @@ void initcatn(long *categs)
 void initcategs(long categs, double *rate)
 { /* initialize category rates for HMM rates */
   long i, loopcount, scanned;
-  char line[100], rest[100];
+  char line[FNMLNGTH], rest[100];
   boolean done;
 
   loopcount = 0;
@@ -624,7 +624,7 @@ void initprobcat(long categs, double *probsum, double *probcat)
 { /* input probabilities of rate categores for HMM rates */
   long i, loopcount, scanned;
   boolean done;
-  char line[100], rest[100];
+  char line[FNMLNGTH], rest[100];
 
   loopcount = 0;
   do {
@@ -1011,7 +1011,7 @@ void initlambda(double *lambda)
 
 void initfreqs(double *freqa, double *freqc, double *freqg, double *freqt)
 { /* input frequencies of the four bases */
-  char input[100];
+  char input[FNMLNGTH];
   long scanned, loopcount;
 
   printf("Base frequencies for A, C, G, T/U (use blanks to separate)?\n");
@@ -2756,7 +2756,7 @@ void exxit(int exitcode)
    * On Windows, supplying a nonzero exitcode will print a message and wait
    * for the user to hit enter. */
 
-#ifdef WIN32
+#ifdef _WIN32
   phyRestoreConsoleAttributes();
 #endif
 
@@ -2874,7 +2874,7 @@ void clear_connections(tree *t, long nonodes)
   }
 }
 
-#ifdef WIN32
+#ifdef _WIN32
 void phySaveConsoleAttributes()
 {
   if ( GetConsoleScreenBufferInfo(hConsoleOutput, &savecsbi) )
@@ -2965,7 +2965,7 @@ void phyClearScreen()
      SetConsoleCursorPosition( hConsoleOutput, coordScreen );
    }
 } /* phyClearScreen */
-#endif /* WIN32 */
+#endif /* _WIN32 */
 
 /* These functions are temporarily used for translating the fixed-width
  * space-padded nayme array to an array of null-terminated char *. */
@@ -3019,9 +3019,9 @@ int fieldwidth_double(double val, unsigned int precision)
   if (precision > 999999)
     abort();
 
-  sprintf(format, "%%.%uf", precision); /* %.Nf */
+  snprintf(format, 10, "%%.%uf", precision); /* %.Nf */
   /* snprintf() would be better, but is it avaliable on all systems? */
-  return sprintf(buf, format, val);
+  return snprintf(buf, sizeof(buf), format, val);
 }
 
 void output_matrix_d(FILE *fp, double **matrix,
