@@ -52,7 +52,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#ifdef WIN32
+#ifdef _WIN32
 #include <windows.h>
 
 void phyClearScreen(void);
@@ -72,7 +72,7 @@ void phyFillScreenColor(void);
 #define MAC
 #endif
 #ifdef __MWERKS__
-#ifndef WIN32
+#ifndef _WIN32
 #define MAC
 #endif
 #endif
@@ -180,7 +180,7 @@ void phyFillScreenColor(void);
 /* default screen types */
 /*  if on a DOS but not a Windows system can use IBM PC screen controls */
 #ifdef DOS
-#ifndef WIN32
+#ifndef _WIN32
 #define IBMCRT true
 #define ANSICRT false
 #endif
@@ -191,7 +191,7 @@ void phyFillScreenColor(void);
 #define ANSICRT false
 #endif
 /*  if on a Windows system can use IBM PC screen controls */
-#ifdef WIN32
+#ifdef _WIN32
 #define IBMCRT true 
 #define ANSICRT false
 #endif
@@ -199,7 +199,7 @@ void phyFillScreenColor(void);
    with ANSI terminal controls */
 #ifndef MAC
 #ifndef DOS
-#ifndef WIN32
+#ifndef _WIN32
 #define IBMCRT false 
 #define ANSICRT true
 #endif
@@ -238,7 +238,7 @@ void phyFillScreenColor(void);
 #ifdef MAC
 #define DELIMITER ':'
 #else 
-#ifdef WIN32
+#ifdef _WIN32
 #define DELIMITER '\\'
 #else 
 #define DELIMITER '/'
