@@ -496,15 +496,15 @@ void R_wtree(node *pere, node *fils, char *s_tree, arbre *tree)
 		if(OUTPUT_TREE_FORMAT == 0)
 			strcat(s_tree,fils->name);
 		else
-			sprintf(s_tree+(int)strlen(s_tree),"%d",fils->num+1);
+			snprintf(s_tree+(int)strlen(s_tree), 10,"%d",fils->num+1);
 		
 		if((fils->b[0]) && (fils->b[0]->l != -1))
 		{
 			strcat(s_tree,":");
-			/* 	  sprintf(s_tree+(int)strlen(s_tree),"%.10f",fils->b[0]->l); */
-			sprintf(s_tree+(int)strlen(s_tree),"%f",fils->b[0]->l);
+			/* 	  snprintf(s_tree+(int)strlen(s_tree),10,"%.10f",fils->b[0]->l); */
+			snprintf(s_tree+(int)strlen(s_tree), 15,"%f",fils->b[0]->l);
 		}
-		sprintf(s_tree+(int)strlen(s_tree),",");
+		strcpy(s_tree+(int)strlen(s_tree), ",");
 	}
 	else
     {
@@ -519,13 +519,13 @@ void R_wtree(node *pere, node *fils, char *s_tree, arbre *tree)
 		if(fils->b[0]->l != -1)
 		{
 			if(tree->print_boot_val)
-				sprintf(s_tree+(int)strlen(s_tree),"%d",fils->b[p]->bip_score);
+				snprintf(s_tree+(int)strlen(s_tree),10,"%d",fils->b[p]->bip_score);
 			else if(tree->print_alrt_val)
-				sprintf(s_tree+(int)strlen(s_tree),"%f",fils->b[p]->ratio_test);
+				snprintf(s_tree+(int)strlen(s_tree), 15,"%f",fils->b[p]->ratio_test);
 			
 			strcat(s_tree,":");
-			/* 	  sprintf(s_tree+(int)strlen(s_tree),"%.10f",fils->b[p]->l); */
-			sprintf(s_tree+(int)strlen(s_tree),"%f",fils->b[p]->l);
+			/* 	  snprintf(s_tree+(int)strlen(s_tree),10,"%.10f",fils->b[p]->l); */
+			snprintf(s_tree+(int)strlen(s_tree),15,"%f",fils->b[p]->l);
 			
 			strcat(s_tree,",");
 		}
