@@ -104,11 +104,10 @@ extern void awake_from_C(void);
 
 
 
-static Char infilename[FNMLNGTH], outfilename[FNMLNGTH], intreename[FNMLNGTH], *outtreename, weightfilename[FNMLNGTH];
+static Char   *outtreename;
 static node *root;
 static long chars, col, msets, ith, njumble, jumb;
 /*   chars = number of sites in actual sequences */
-static long inseed, inseed0;
 static boolean jumble, usertree, weights, thresh, trout, progress, stepbox,
     justwts, ancseq, mulsets, firstset;
 codetype whichcode;
@@ -478,7 +477,7 @@ static void getoptions()
           loopcount2 = 0;
           do {
             printf(" (type D or W)\n");
-#ifdef WIN32
+#ifdef _WIN32
             phyFillScreenColor();
 #endif
             fflush(stdout);
@@ -1987,7 +1986,7 @@ static void maketree(char *toevaluate)
       }
     }
   } else {
-    /* Open in binary: ftell() is broken for UNIX line-endings under WIN32 */
+    /* Open in binary: ftell() is broken for UNIX line-endings under _WIN32 */
     //openfile(&intree,INTREE,"input tree file", "rb",progname,intreename);
     //numtrees = countsemic(&intree);
     numtrees = 1;
