@@ -13,7 +13,7 @@
 #include <sys/socket.h>
 #include <sys/time.h>
 #include <termios.h>
-#elif defined(WIN32)
+#elif defined(_WIN32)
 #if _WIN32_WINNT < 0x0501
 #define _WIN32_WINNT  0x0501
 #endif
@@ -47,7 +47,7 @@ void (*raa_error_mess_proc)(raa_db_access *, char *) = NULL;
 
 #define MAX_RDSHRT 50 /* max short list length read in one time */
 
-#if defined(WIN32)
+#if defined(_WIN32)
 
 static int socket_getc(raa_db_access *raa_current_db, SOCKET f)
 {
@@ -144,7 +144,7 @@ if(raa_current_db == NULL) return EOF;
 return fflush(raa_current_db->raa_sockfdw);
 }
 
-#endif /* WIN32 */
+#endif /* _WIN32 */
 
 
 static int sock_printf(raa_db_access  *raa_current_db, const char *fmt, ...)
@@ -171,7 +171,7 @@ static char *read_sock_tell(raa_db_access *raa_current_db, int *wascompleteline)
   if(raa_current_db == NULL || raa_current_db->was_here) return NULL;
   sock_flush(raa_current_db); /* tres important */
   isfull = FALSE;
-#if defined(WIN32)
+#if defined(_WIN32)
   p = sock_fgets(raa_current_db, raa_current_db->buffer, sizeof(raa_current_db->buffer));
 #else
   p = fgets(raa_current_db->buffer, sizeof(raa_current_db->buffer), raa_current_db->raa_sockfdr);
@@ -181,7 +181,9 @@ static char *read_sock_tell(raa_db_access *raa_current_db, int *wascompleteline)
 		raa_current_db->was_here = TRUE;
 		*raa_current_db->buffer = 0;
 		if(raa_current_db != NULL && raa_current_db->dbname != NULL) {
-			sprintf(raa_current_db->buffer, "%s: ", raa_current_db->dbname);
+			snprintf(raa_current_db->buffer,
+                                 strlen(raa_current_db->dbname)+3, "%s: ",
+                                 raa_current_db->dbname);
 			}
 		strcat(raa_current_db->buffer, ( p == NULL ?
   			"Error: connection to acnuc server is down. Please try again."
@@ -234,7 +236,7 @@ fd_set readfds;
 struct timeval tout;
 int err;
 
-#if defined(WIN32)
+#if defined(_WIN32)
 SOCKET fd;
 if(raa_current_db == NULL) return NULL;
 fd = (SOCKET)(raa_current_db->raa_sockfdr);
@@ -311,7 +313,7 @@ clientid: NULL or a string identifying the client
   struct addrinfo *ai;
   char *reponse, portstring[10];
   int err;
-#ifdef WIN32
+#ifdef _WIN32
 WSADATA mywsadata;
 SOCKET raa_snum;
 #else
@@ -321,7 +323,7 @@ int raa_snum;
 raa_current_db = (raa_db_access *)calloc(1, sizeof(raa_db_access));
 if(raa_current_db == NULL) return nomemory; /* not enough memory */
   /* cration de la socket */
-#ifdef WIN32
+#ifdef _WIN32
   err = WSAStartup(MAKEWORD(2,2), &mywsadata); /* indispensable avant utilisation socket */
   if (err == 0) raa_snum = WSASocket(AF_INET, SOCK_STREAM, IPPROTO_TCP, NULL, (GROUP)0, 0);
   if (err != 0 || raa_snum == INVALID_SOCKET) {
@@ -336,7 +338,7 @@ if(raa_current_db == NULL) return nomemory; /* not enough memory */
   	}
 #endif
 /* cration de deux flux type FILE * */
-#if defined(WIN32)
+#if defined(_WIN32)
 raa_current_db->raa_sockfdr = (FILE *)raa_snum;
 raa_current_db->raa_sockfdw = (FILE *)raa_snum;
 #else
@@ -344,7 +346,7 @@ raa_current_db->raa_sockfdr = fdopen(raa_snum,"r");
 raa_current_db->raa_sockfdw = fdopen(raa_snum,"a");
 #endif
 
-  sprintf(portstring, "%d", port);
+  snprintf(portstring, sizeof(portstring), "%d", port);
   err = getaddrinfo(serveurName, portstring, NULL, &ai);
   if (err) {
     free(raa_current_db);
@@ -416,7 +418,7 @@ if(raa_current_db == NULL) return nosocket;
 	/* reply = MD5 of challenge:db_name:MD5(password) */
 	raa_MD5String(password, reply);
 	memset(password, 0, strlen(password));
-	sprintf(tmp, "%s:%s:%s", challenge, db_name, reply);
+	snprintf(tmp, 300, "%s:%s:%s", challenge, db_name, reply);
 	raa_MD5String(tmp, reply);
 	memset(tmp, 0, strlen(tmp));
 	sock_printf(raa_current_db, "reply=%s\n", reply);
@@ -437,7 +439,7 @@ if (codret != 0) {
   raa_current_db->nextelt_data.current_rank = -1;
   raa_current_db->nextelt_data.previous = -2;
   raa_current_db->readshrt_data.shrt_begin = S_BUF_SHRT - 1;
-#ifdef WIN32
+#ifdef _WIN32
   raa_current_db->sock_input_pos = raa_current_db->sock_input; raa_current_db->sock_input_end = raa_current_db->sock_input;
 #endif
   p = val(rep,"type");
@@ -659,7 +661,7 @@ if(reponse != NULL) {
 	sock_fputs(raa_current_db, "quit\n"); 
 	sock_flush(raa_current_db);
 	}
-#ifdef WIN32
+#ifdef _WIN32
   closesocket( (SOCKET) (raa_current_db->raa_sockfdw) );
 #else
   fclose(raa_current_db->raa_sockfdr);
@@ -782,8 +784,9 @@ if(raa_current_db == NULL) return -1;
   if(requete == NULL) {
   	if(message != NULL) {
 		char fmt[] = "problem accessing file: %s";
-  		*message = (char *)malloc(strlen(fmt) + strlen(badfname) + 1);
-  		sprintf(*message, fmt, badfname);
+                int lmessage = strlen(fmt) + strlen(badfname) + 1;
+  		*message = (char *)malloc(lmessage);
+  		snprintf(*message, lmessage, fmt, badfname);
   		}
   	return 1;
   	}
@@ -916,7 +919,7 @@ return val;
 
 char *print_raa_long(raa_long val, char *buffer)
 {
-sprintf(buffer, RAA_LONG_FORMAT, val);
+snprintf(buffer, 20, RAA_LONG_FORMAT, val);
 return buffer;
 }
 
@@ -2287,7 +2290,7 @@ code = atoi(q);
 free(q);
 if(code != 0) {
 	if(code == 3) strcpy(line, "too many lists, delete a few");
-	else sprintf(line, "code=%d", code);
+	else snprintf(line, 20, "code=%d", code);
 	return NULL;
 	}
 q = val(rep,"name");
@@ -2646,21 +2649,21 @@ char *line;
 int *v, maxi, **table, rank;
 struct coord_series_struct *retval;
 	
-sprintf(message, "extractseqs&%s=%d&format=coordinates&operation=%s", 
+snprintf(message, 200, "extractseqs&%s=%d&format=coordinates&operation=%s",
 	seqnum == 0 ? "lrank" : "seqnum", 
 	seqnum == 0 ? lrank : seqnum, 
 	operation);
 sock_fputs(raa_current_db, message);
 if(strcmp(operation, "feature") == 0 || strcmp(operation, "region") == 0) {
-	sprintf(message, "&feature=%s", feature_name);
+	snprintf(message, 200, "&feature=%s", feature_name);
 	sock_fputs(raa_current_db, message);
 	}
 if(strcmp(operation, "fragment") == 0 || strcmp(operation, "region") == 0) {
-	sprintf(message, "&bounds=%s", bounds);
+	snprintf(message, 200, "&bounds=%s", bounds);
 	sock_fputs(raa_current_db, message);
 	}
 if(min_bounds != NULL) {
-	sprintf(message, "&minbounds=%s", min_bounds);
+	snprintf(message, 200, "&minbounds=%s", min_bounds);
 	sock_fputs(raa_current_db, message);
 	}
 sock_fputs(raa_current_db, "\n"); sock_flush(raa_current_db);
