@@ -5,7 +5,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
-#if defined(WIN32)
+#if defined(_WIN32)
 #define SOCKBUFS 8192
 #endif
 #ifdef __alpha
@@ -131,10 +131,10 @@ typedef struct _raa_db_access {
 	int tot_key_annots;
 	char **key_annots, **key_annots_min;
 	unsigned char *want_key_annots;
-#ifdef WIN32
-	char sock_input[SOCKBUFS]; /* WIN32 socket input buffer */
+#ifdef _WIN32
+	char sock_input[SOCKBUFS]; /* _WIN32 socket input buffer */
 	char *sock_input_pos, *sock_input_end;
-	char sock_output[SOCKBUFS]; /* WIN32 socket output buffer */
+	char sock_output[SOCKBUFS]; /* _WIN32 socket output buffer */
 	unsigned sock_output_lbuf;
 #endif
   char buffer[5000];
