@@ -5,7 +5,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-#ifdef WIN32
+#ifdef _WIN32
 #include <winsock.h>
 #endif
 #include <zlib.h>
@@ -26,7 +26,7 @@ typedef struct {
 	char z_buffer[ZBSIZE]; /* compressed input buffer */
 	char text_buffer[4 * ZBSIZE]; /* decompressed buffer */
 	char *pos, *endbuf;
-#ifdef WIN32
+#ifdef _WIN32
 	SOCKET fd;
 #else
 	int fd;
@@ -50,7 +50,7 @@ big->stream.zfree = Z_NULL;
 big->stream.opaque = NULL;
 big->pos = big->text_buffer;
 big->endbuf = big->pos;
-#ifdef WIN32
+#ifdef _WIN32
 big->fd = (SOCKET)sockr;
 #else
 big->fd = fileno(sockr);
@@ -76,7 +76,7 @@ big->pos = (char *)zs->next_out;
 do	{
 	if(zs->avail_in == 0) {
 		int lu;
-#ifdef WIN32
+#ifdef _WIN32
 		lu = recv( big->fd , big->z_buffer, ZBSIZE, 0 );
 #else
 		lu = read( big->fd , big->z_buffer, ZBSIZE );
