@@ -445,20 +445,20 @@ coloraas *mycoloraas = (coloraas *)data;
 accept_cb(NULL, data);
 
 v = (int)(bgrnd->value() + 0.5);
-sprintf(txt, "%d", v );
+snprintf(txt, sizeof(txt), "%d", v );
 set_res_value("background", txt );
 v = (int)(s_bgrnd->value() + 0.5);
-sprintf(txt, "%d", v );
+snprintf(txt, sizeof(txt), "%d", v );
 set_res_value("sites_background", txt );
 
 Fl::get_color( A->color(), r, g, b);
-sprintf(txt, "%d %d %d,", r, g, b);
+snprintf(txt, sizeof(txt), "%d %d %d,", r, g, b);
 Fl::get_color( C->color(), r, g, b);
-sprintf(txt + strlen(txt), "%d %d %d,", r, g, b);
+snprintf(txt + strlen(txt), sizeof(txt)-strlen(txt), "%d %d %d,", r, g, b);
 Fl::get_color( G->color(), r, g, b);
-sprintf(txt + strlen(txt), "%d %d %d,", r, g, b);
+snprintf(txt + strlen(txt), sizeof(txt)-strlen(txt), "%d %d %d,", r, g, b);
 Fl::get_color( T->color(), r, g, b);
-sprintf(txt + strlen(txt), "%d %d %d", r, g, b);
+snprintf(txt + strlen(txt), sizeof(txt)-strlen(txt), "%d %d %d", r, g, b);
 set_res_value("dnacolors", txt);
 
 set_res_value("stdcolorgroups", (char *)protgroups->value());
@@ -467,7 +467,7 @@ set_res_value("altcolorgroups", (char *)s_protgroups->value());
 txt[0] = 0;
 for(int c=1; c < max_protcolors; c++) {
 	Fl::get_color( protcol[c]->color(), r, g, b);
-	sprintf(txt + strlen(txt), "%d %d %d,", r, g, b);
+	snprintf(txt + strlen(txt), sizeof(txt)-strlen(txt), "%d %d %d,", r, g, b);
 	}
 txt[strlen(txt) - 1] = 0;
 set_res_value("protcolors", txt);
@@ -477,10 +477,10 @@ set_res_value("lowercase", lowercase->value() ? "true" : "false");
 set_res_value("inverted", inverted->value() ? "true" : "false");
 set_res_value("spacesinfastanames", fastaspaces->value() ? "true" : "false");
 set_res_value("printoutpageformat", printout_pageformat == Fl_Paged_Device::A4 ? "A4" : "LETTER" );
-sprintf(txt, "%d", (int)pdffontsize->value() );
+snprintf(txt, sizeof(txt), "%d", (int)pdffontsize->value() );
 set_res_value("printoutfontsize",  txt);
 
-sprintf(txt, "%d", (int)phylipwidnames->value() );
+snprintf(txt, sizeof(txt), "%d", (int)phylipwidnames->value() );
 set_res_value("phylipwidnames",  txt);
 
 strcpy(txt, f_format_names[saveformat->value()] );
@@ -488,12 +488,14 @@ minuscules(txt);
 set_res_value("save", txt );
 
 v = alignment_algo->value();
-sprintf(txt, "%d", v );
+snprintf(txt, sizeof(txt), "%d", v );
 set_res_value("alignment", txt);
 	
 p = txt;
+int lp = sizeof(txt);
 for(i = 0; i < 21; i++) {
-	sprintf(p, "%c:%d,", aminoacids[i], mycoloraas->codoncolors[i+1]);
+	snprintf(p, lp, "%c:%d,", aminoacids[i], mycoloraas->codoncolors[i+1]);
+        lp -= strlen(p);
 	p += strlen(p);
 	}
 *(p-1) = 0;
@@ -515,7 +517,7 @@ if(data == A) {
 	}
 else if(data == bgrnd) {
 	int back_color, region_back_color;
-#ifdef WIN32
+#ifdef _WIN32
 	back_color = FL_DARK1; region_back_color = 43;
 #else
 	back_color = FL_GRAY; region_back_color = FL_DARK2;
