@@ -658,15 +658,15 @@ char *write_unrooted(noeud centre, char *tree_start)
 	else if(centre->v2 == NULL && centre->v3 == NULL) centre = centre->v1;
 	
 	tree = write_rooted(centre->v1, centre, tree);
-	sprintf(tree, ":%.5f,", centre->l1);
+	snprintf(tree, 100, ":%.5f,", centre->l1);
 	tree += strlen(tree);
 	
 	tree = write_rooted(centre->v2, centre, tree);
-	sprintf(tree, ":%.5f,", centre->l2);
+	snprintf(tree, 100, ":%.5f,", centre->l2);
 	tree += strlen(tree);
 
 	tree = write_rooted(centre->v3, centre, tree);
-	sprintf(tree, ":%.5f);", centre->l3);
+	snprintf(tree, 100, ":%.5f);", centre->l3);
 	
 	return tree_start;
 }
@@ -685,10 +685,10 @@ char *write_rooted(noeud centre, noeud from, char *tree)
 	else {
 		*tree++ = '(';
 		tree = write_rooted(d, centre, tree);
-		sprintf(tree, ":%.5f,", ld);
+		snprintf(tree, 50, ":%.5f,", ld);
 		tree += strlen(tree);
 		tree = write_rooted(g, centre, tree);
-		sprintf(tree, ":%.5f)", lg);
+		snprintf(tree, 50, ":%.5f)", lg);
 		}
 	tree += strlen(tree);
 	return tree;
