@@ -210,9 +210,9 @@ void load_seq_dialog(SEA_VIEW *view)
   
   curr_y += top->h() + 15;
   seq_input = new Fl_Input(top->x(), curr_y, load_form->w() - 2 * top->x(), 450,
-#if defined(__APPLE__)
+#if defined(FLTK_COCOA_PLATFORM)
 	    ""
-#elif defined(WIN32) 
+#elif defined(_WIN32) 
 	    "Type sequence or paste it with CRTL-V in panel below"
 #else
 	    "Type or paste sequence with middle mouse button in panel below"
@@ -261,9 +261,9 @@ void load_seq_dialog(SEA_VIEW *view)
   seq_name_input->value("");
   seq_input->value("");
   view_name.view = view;
-#if defined(__APPLE__)
+#if defined(FLTK_COCOA_PLATFORM)
 	seq_input->value("\n\n\n\n\n\nType sequence or paste it with cmd-V\n\n\n");
-	seq_input->position(seq_input->size(), 0);
+	seq_input->insert_position(seq_input->size(), 0);
 #endif	
   seq_input->take_focus();
   load_form->show();
@@ -591,7 +591,11 @@ temp = renumber_seq(editdata->view->sequence[editdata->seqnum]);
 if(temp == NULL) return TRUE;
 editdata->input->value(temp);
 free(temp);
-editdata->input->position(0);
+#if 10000*FL_MAJOR_VERSION + 100*FL_MINOR_VERSION >= 10400
+  editdata->input->insert_position(0);
+#else
+  editdata->input->position(0);
+#endif
 return FALSE;
 }
 
@@ -608,16 +612,18 @@ while(*(++p) != 0) {
 	if(ISSEQCHAR(*p)) l++;
 	}
 nl = l / w + 2;
-temp = (char *)malloc(l + 7 * nl + 100);
+int ltemp = l + 7 * nl + 100;
+temp = (char *)malloc(ltemp);
 if(temp == NULL) return NULL;
 p = seq - 1;
 q = temp;
 pos = 0;
 while(*(++p) != 0) {
 	if( ! ISSEQCHAR(*p)) continue;
-	*q++ = *p; pos++;
+        *q++ = *p; pos++; ltemp--;
 	if(pos % w == 0) {
-		sprintf(q, "%6d\n", pos);
+		snprintf(q, ltemp, "%6d\n", pos);
+                ltemp -= strlen(q);
 		q += strlen(q);
 		}
 	}
@@ -764,7 +770,11 @@ while( *p != 0);
 *r = 0;
 input->value(temp);
 free(temp);
+#if 10*FL_MAJOR_VERSION + FL_MINOR_VERSION >= 14
+  input->insert_position(0);
+#else
 input->position(0);
+#endif
 return FALSE;
 }
 
@@ -885,6 +895,6 @@ for (pos = 0; pos < view->seq_length; pos++) {
 		}
 	newseq[pos + 1] = 0;
 	}
-sprintf(newname, "Consensus%d", view->consensus_threshold);
+snprintf(newname, 50, "Consensus%d", view->consensus_threshold);
 return newseq;
 }
