@@ -1,4 +1,5 @@
 #ifdef __APPLE__
+#define GL_SILENCE_DEPRECATION 1
 #import <Cocoa/Cocoa.h>
 #include "seaview.h"
 #include "pdf_or_ps.h"
@@ -65,7 +66,7 @@ const char *MG_GetBundleResourcesDir(void)
 
 static void label(int x, int y, int w, int h, const char *text, NSView *view)
 {
-  NSRect rect = {{x, y}, {w, h}};
+  NSRect rect = {{(CGFloat)x, (CGFloat)y}, {(CGFloat)w, (CGFloat)h}};
   NSTextField *label = [[[NSTextField alloc] initWithFrame:rect] autorelease];
   [label setStringValue:[[[NSString alloc] initWithUTF8String:text] autorelease]];
   [label setEditable:NO];
@@ -119,18 +120,18 @@ char *mac_GetOutputFName_Plus(const char *dfault, const char *message, int use_o
   [pdfmatrix setAllowsEmptySelection:NO];
   NSSize spacing= {0, 2};
   [pdfmatrix setIntercellSpacing:spacing];
-  NSSize cellsize= {80, 16};
+  NSSize cellsize= {100, 16};
   [pdfmatrix setCellSize:cellsize];
   NSButton *color = [[[NSButton alloc] init] autorelease];
-  [color setButtonType:radio_button_style];
+  [color setButtonType:(NSButtonType)radio_button_style];
   [color setTitle:@"PDF color"];
   [pdfmatrix putCell:[color cell] atRow:0 column:0];
   NSButton *bw = [[[NSButton alloc] init] autorelease];
-  [bw setButtonType:radio_button_style];
+  [bw setButtonType:(NSButtonType)radio_button_style];
   [bw setTitle:@"PDF B&W"];
   [pdfmatrix putCell:[bw cell] atRow:1 column:0];
   NSButton *textfile = [[[NSButton alloc] init] autorelease];
-  [textfile setButtonType:radio_button_style];
+  [textfile setButtonType:(NSButtonType)radio_button_style];
   [textfile setTitle:@"Text File"];
   [pdfmatrix putCell:[textfile cell] atRow:2 column:0];
   [pdfmatrix selectCell:[bw cell]];
@@ -145,11 +146,11 @@ char *mac_GetOutputFName_Plus(const char *dfault, const char *message, int use_o
   [papermatrix setIntercellSpacing:spacing];
   [papermatrix setCellSize:cellsize];
   NSButton *A4 = [[[NSButton alloc] init] autorelease];
-  [A4 setButtonType:radio_button_style];
+  [A4 setButtonType:(NSButtonType)radio_button_style];
   [A4 setTitle:@"A4"];
   [papermatrix putCell:[A4 cell] atRow:0 column:0];
   NSButton *LETTER = [[[NSButton alloc] init] autorelease];
-  [LETTER setButtonType:radio_button_style];
+  [LETTER setButtonType:(NSButtonType)radio_button_style];
   [LETTER setTitle:@"LETTER"];
   [papermatrix putCell:[LETTER cell] atRow:1 column:0];
   [papermatrix selectCell:[LETTER cell]];
@@ -159,7 +160,7 @@ char *mac_GetOutputFName_Plus(const char *dfault, const char *message, int use_o
 // landscape button
   NSRect landscaperect = {{305, 6}, {80, 20} };
   NSButton *landscape = [[[NSButton alloc] initWithFrame:landscaperect] autorelease];
-  [landscape setButtonType:switch_button_style];
+  [landscape setButtonType:(NSButtonType)switch_button_style];
   [landscape setTitle:@"landscape"];
   [landscape sizeToFit];
   [landscape setIntValue:(printout_layout == Fl_Paged_Device::LANDSCAPE)];
@@ -168,7 +169,7 @@ char *mac_GetOutputFName_Plus(const char *dfault, const char *message, int use_o
 //variable site button  
   NSRect variablerect = {{385, 25}, {80, 20} };
   NSButton *variable = [[[NSButton alloc] initWithFrame:variablerect] autorelease];
-  [variable setButtonType:switch_button_style];
+  [variable setButtonType:(NSButtonType)switch_button_style];
   [variable setTitle:@"variable sites only"];
   [variable sizeToFit];
   [variable setIntValue:printout_vary];
@@ -193,7 +194,10 @@ char *mac_GetOutputFName_Plus(const char *dfault, const char *message, int use_o
   else
 #endif
   {
-    retval = [(id)_panel runModalForDirectory:dir file:fname];
+    // Replace this to avoid deprecation warning message:
+    //retval = [(id)_panel runModalForDirectory:dir file:fname];
+    retval = (int)(fl_intptr_t)[_panel performSelector:@selector(runModalForDirectory:file:)
+                            withObject:dir withObject:fname];
   }
   [key makeKeyWindow];
   [preset release];
@@ -240,7 +244,7 @@ int add_windowmenuitem(const char *name, Fl_Window *w)
 {
   if(fl_sys_menu_bar == NULL) new Fl_Sys_Menu_Bar(0,0,0,0,NULL);
   char line[200];
-  sprintf(line, "Window/%s", name ? name : "<empty>");
+  snprintf(line, 200, "Window/%s", name ? name : "<empty>");
   int val = fl_sys_menu_bar->add(line, 0, windowmenuitem_callback, w);
   return val;
 }
@@ -373,231 +377,6 @@ void set_seaview_modified(SEA_VIEW *view, int ismodified)
   [(NSWindow*)(fl_xid(view->dnawin)) setDocumentEdited:ismodified];
 }
 
-#ifdef USE_PICT
-class Fl_PICT_Graphics_Driver : public Fl_Graphics_Driver {
-protected:
-  void rect(int x, int y, int w, int h);
-  void rectf(int x, int y, int w, int h);
-  void line_style(int style, int width, char *dashes=0);
-  void line(int x1, int y1, int x2, int y2);
-  void font(int f, int s);
-  void draw(const char *str, int n, int x, int y);
-  void draw(const char*, int, float, float) ;
-  void draw(int, const char*, int, int, int) ;
-  void rtl_draw(const char*, int, int, int) ;
-  void color(uchar r, uchar g, uchar b);
-  void color(Fl_Color c);
-  void draw_image(const uchar*, int, int, int, int, int, int) ;
-  void draw_image_mono(const uchar*, int, int, int, int, int, int) ;
-  void draw_image(void (*)(void*, int, int, int, uchar*), void*, int, int, int, int, int) ;
-  void draw_image_mono(void (*)(void*, int, int, int, uchar*), void*, int, int, int, int, int) ;
-  void draw(Fl_RGB_Image*, int, int, int, int, int, int) ;
-  void draw(Fl_Pixmap*, int, int, int, int, int, int) ;
-  void draw(Fl_Bitmap*, int, int, int, int, int, int) ;
-  double width(const char*, int) ;
-  int height() ;
-  int descent() ;
-};
-
-void Fl_PICT_Graphics_Driver::draw(const char *txt, int n, int x, int y)
-{
-  if(txt == NULL || n == 0) return;
-  MoveTo(x, y);
-  unsigned char copy[n + 1];
-  memcpy(copy+1, txt, n); *copy = n;
-  DrawString(copy);
-}
-
-void Fl_PICT_Graphics_Driver::line(int x, int y, int x1, int y1)
-{
-  MoveTo(x, y);
-  LineTo(x1, y1);
-}
-
-void Fl_PICT_Graphics_Driver::rect(int x, int y, int w, int h)
-{
-  MoveTo(x, y);
-  LineTo(x, y+h-1);
-  LineTo(x+w-1, y+h-1);
-  LineTo(x+w-1, y);
-  LineTo(x, y);
-}
-
-void Fl_PICT_Graphics_Driver::rectf(int x, int y, int w, int h)
-{
-  Rect r;
-  r.top = (short)y;
-  r.left = (short)x;
-  r.bottom = (short)(y+h);
-  r.right = (short)(x+w);
-  PaintRect(&r);
-}
-
-void Fl_PICT_Graphics_Driver::font(int fontrank, int size)
-{
-  Style mystyle = normal;
-  int macfont, fontstyle;
-  if(fontrank < FL_SYMBOL) {
-    fontstyle = fontrank % 4;
-    fontrank -= fontstyle;
-  }
-  if(fontrank == FL_COURIER)
-    macfont=kFontIDCourier/*22*/;
-  else if(fontrank == FL_HELVETICA)
-    macfont=kFontIDHelvetica/*21*/;
-  else if(fontrank == FL_TIMES)
-    macfont=kFontIDTimes/*20*/;
-  else if(fontrank == FL_SYMBOL)
-    macfont=kFontIDSymbol/*23*/;
-  else
-    macfont=21; 
-  if(fontrank < FL_SYMBOL) {
-    if(fontstyle == 0) mystyle = normal;
-    else if(fontstyle == 1) mystyle = bold;
-    else if(fontstyle == 2) mystyle = italic;
-    else if(fontstyle == 3) mystyle = bold+italic;
-  }
-  TextFont(macfont);
-  TextSize(size);
-  TextFace(mystyle);
-  Fl_Display_Device::display_device()->driver()->font(fontrank, size);
-}
-
-void Fl_PICT_Graphics_Driver::color(Fl_Color color)
-{
-  unsigned char r, g, b;
-  Fl::get_color(color, r, g, b);
-  RGBColor maccolor;
-  maccolor.red = r << 8;
-  maccolor.green = g << 8;
-  maccolor.blue = b << 8;
-  RGBForeColor(&maccolor);
-}
-
-double Fl_PICT_Graphics_Driver::width(const char *txt, int l)
-{
-  return (double)TextWidth( txt, 0, l );
-}
-
-void Fl_PICT_Graphics_Driver::draw_image(const uchar*, int, int, int, int, int, int) {}
-void Fl_PICT_Graphics_Driver::draw_image_mono(const uchar*, int, int, int, int, int, int) {}
-void Fl_PICT_Graphics_Driver::draw_image(void (*)(void*, int, int, int, uchar*), void*, int, int, int, int, int) {}
-void Fl_PICT_Graphics_Driver::draw_image_mono(void (*)(void*, int, int, int, uchar*), void*, int, int, int, int, int) {}
-void Fl_PICT_Graphics_Driver::draw(Fl_RGB_Image*, int, int, int, int, int, int) {}
-void Fl_PICT_Graphics_Driver::draw(Fl_Pixmap*, int, int, int, int, int, int) {}
-void Fl_PICT_Graphics_Driver::draw(Fl_Bitmap*, int, int, int, int, int, int) {}
-void Fl_PICT_Graphics_Driver::line_style(int style, int width, char *dashes) {}
-void Fl_PICT_Graphics_Driver::color(uchar r, uchar g, uchar b) {}
-void Fl_PICT_Graphics_Driver::rtl_draw(const char*, int, int, int) {}
-void Fl_PICT_Graphics_Driver::draw(int angle, const char* str, int n, int x, int y) {}
-int Fl_PICT_Graphics_Driver::height() {
-  return Fl_Display_Device::display_device()->driver()->height();
-}
-int Fl_PICT_Graphics_Driver::descent() {
-  return Fl_Display_Device::display_device()->driver()->descent();
-}
-void Fl_PICT_Graphics_Driver::draw(const char* str, int n, float fx, float fy) {
-  draw(str, n, (int)fx, (int)fy);
-}
-
-Copy_Surface::Copy_Surface(int w, int h) : Fl_Surface_Device(NULL)
-{
-  Rect myrect;
-  myrect.top=0;
-  myrect.left=0;
-  myrect.right=w;
-  myrect.bottom=h;
-  mypicture = OpenPicture(&myrect);
-  ClipRect(&myrect);
-  PenNormal();
-  driver(new Fl_PICT_Graphics_Driver());
-}
-
-Copy_Surface::~Copy_Surface()
-{
-  ClosePicture();
-  MyCopyPictToClipboard();
-  KillPicture(mypicture);
-  delete driver();
-}
-
-QDPictRef Copy_Surface::MyPictToQDPict()
-{
-  CFIndex pictlen;
-  CGDataProviderRef provider;
-  /* conversion picture to QDPict */
-  pictlen = GetHandleSize( (Handle)  mypicture);
-  HLock( (Handle) mypicture);
-  provider = CGDataProviderCreateWithData (NULL, *mypicture, pictlen, NULL);
-  HUnlock( (Handle) mypicture);
-  if (provider != NULL) {
-	  QDPictRef myqdpict = QDPictCreateWithProvider (provider);
-	  CFRelease(provider);
-	  return myqdpict;
-  }
-  return NULL;
-}
-
-
-void Copy_Surface::MyCopyPictToClipboard()
-{
-  CFDataRef  data = NULL;
-  PasteboardRef clipboard = NULL;
-  CFIndex pictlen;
-  
-  pictlen = GetHandleSize( (Handle)  mypicture);
-  PasteboardCreate (kPasteboardClipboard, &clipboard);
-  PasteboardClear(clipboard);
-  HLock( (Handle) mypicture);
-  data = CFDataCreate( kCFAllocatorDefault, (UInt8*)*mypicture, pictlen );
-  HUnlock( (Handle) mypicture);
-  PasteboardPutItemFlavor(clipboard, (PasteboardItemID)1, 
-				      /* kUTTypePICT */ CFSTR("com.apple.pict"),
-				      data,
-				      kPasteboardFlavorNoFlags );
-  CFRelease (data);
-  QDPictRef myqdpict = (fl_mac_os_version >= 100400 ? MyPictToQDPict() : 0); // useful under 10.3 for unclear reason
-  if (!myqdpict) {
-    CFRelease(clipboard);
-    return;
-  }
-  
-  CGRect bounds = QDPictGetBounds (myqdpict);
-  CFMutableDataRef pdfdata;
-  CGContextRef gc = init_PDF_context(bounds.size.width, bounds.size.height, pdfdata);
-  if (gc) {
-    /* convert PICT to PDF */
-    CGContextBeginPage (gc, &bounds);
-    (void) QDPictDrawToCGContext (gc, bounds, myqdpict);
-    CGContextEndPage (gc);
-    CGContextRelease (gc);
-    /* copy PDF to clipboard */
-    (void) PasteboardPutItemFlavor (clipboard, (PasteboardItemID)1, 
-				     /* kUTTypePDF */ CFSTR("com.adobe.pdf"), 
-				     pdfdata, kPasteboardFlavorNoFlags);
-    CFRelease (pdfdata);
-  }
-  CFRelease (clipboard);
-  QDPictRelease(myqdpict);
-}
-
-
-CGContextRef Copy_Surface::init_PDF_context(int w, int h, CFMutableDataRef &pdfdata)
-{
-#if MAC_OS_X_VERSION_MAX_ALLOWED >= 1040
-  CGRect bounds = CGRectMake(0, 0, w, h );
-  pdfdata = CFDataCreateMutable(NULL, 0);
-  if (&CGDataConsumerCreateWithCFData) { // true from 10.4
-    CGDataConsumerRef myconsumer = CGDataConsumerCreateWithCFData (pdfdata);
-    CGContextRef gc = CGPDFContextCreate (myconsumer, &bounds, NULL);
-    CGDataConsumerRelease (myconsumer);
-    return gc;
-  }
-#endif
-  return NULL;
-}
-
-#endif // USE_PICT
 
 void mac_tmp_dir_name(char *buffer, int l)
 {
