@@ -791,7 +791,7 @@ char *replace_ranks_by_names(char *tree, int ntaxa, char **taxnames)
       *r = 0;
       if ( strncmp(bootstrap_comment, "[&prob=", 7) == 0) {
 	sscanf(bootstrap_comment + 7, "%f", &pp);
-	sprintf(q, "%.2f", pp);
+	snprintf(q, 20, "%.2f", pp);
 	q += strlen(q);
 	}
       continue;
@@ -799,7 +799,7 @@ char *replace_ranks_by_names(char *tree, int ntaxa, char **taxnames)
     if ( (*p == '(' || *p == ',') && isdigit(*(p+1))) { // a taxon rank is found
       *q++ = *p++;
       sscanf(p, "%d", &rank);
-      sprintf(q, "%s", taxnames[rank - 1]);
+      strcpy(q, taxnames[rank - 1]);
       q += strlen(q);
       p++;
       while (isdigit(*p)) p++;
@@ -1343,7 +1343,7 @@ while(*(++q) != 0) {
 	}
 if(!protect) return p;
 else 	{
-	sprintf(out, "'%s'", out_with_apostrophe(p));
+	snprintf(out, sizeof(out), "'%s'", out_with_apostrophe(p));
 	return out;
 	}
 }
