@@ -50,11 +50,11 @@ PDF_or_PS_File_Device::~PDF_or_PS_File_Device()
   } 
 }
 
-#else // NO_PDF
+#elif 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION < 140
 
 #include <pdflib.h>
 #include <setjmp.h>
-#ifdef WIN32
+#ifdef _WIN32
 extern PDF *win32_PDF_new();
 extern int win32_PDF_begin_document(PDF *p, const char *filename, int len, const char *optlist);
 extern void win32_PDF_end_document(PDF *p, const char *optlist);
@@ -63,7 +63,7 @@ extern void win32_PDF_delete(PDF *p);
 #define PDF_end_document win32_PDF_end_document
 #define PDF_new win32_PDF_new
 #define PDF_delete win32_PDF_delete
-#endif // WIN32
+#endif // _WIN32
 
 Fl_PDF_File_Device::Fl_PDF_File_Device()
 {
@@ -247,7 +247,7 @@ void Fl_PDF_File_Device::surface_try(jmp_buf **jbuf)
 
 PDF_Graphics_Driver::PDF_Graphics_Driver()
 {
-#ifdef __APPLE__
+#ifdef FLTK_COCOA_PLATFORM
   encoding	= "macroman";
 #else
   encoding	= "iso8859-1";
