@@ -170,9 +170,9 @@ if(doit) {
 	mnemo = import_one_seq(runningw_data->raa, line, runningw_data->use_spec_name, &length, 
 		&runningw_data->truncated, runningw_data->view, FALSE, 0, NULL);
 	if(mnemo != NULL) 
-		sprintf(aux, "Name: %s Count: %d", mnemo, ++runningw_data->count);
+		snprintf(aux, sizeof(aux), "Name: %s Count: %d", mnemo, ++runningw_data->count);
 	else
-		sprintf(aux, "Name: %s not found", line);
+		snprintf(aux, sizeof(aux), "Name: %s not found", line);
 	runningw_data->runb->label(aux);
 	runningw_data->runb->window()->redraw();
 	}
@@ -293,7 +293,7 @@ void use_key_callback(Fl_Widget *ob, void *data)
 	int num, total;
 	raa_dialog_struct *raa_fields = (raa_dialog_struct *)data;
 	raa_fields->key_choice->clear();
-	raa_fields->scan_field->value(NULL);
+	raa_fields->scan_field->value("");
 	if(((Fl_Button *)ob)->value() ) {
 		raa = open_acnuc_socket(raa_fields->ok, raa_fields->close_b);
 		if(raa == NULL || raa_opendb(raa, (char *)raa_fields->dbchoice->text()) || raa->swissprot) {
@@ -508,76 +508,78 @@ raa_db_access *open_acnuc_socket(Fl_Widget *ok, Fl_Button *close_b)
 char *import_one_seq(raa_db_access *raa, const char *id, int use_spec_name, int *plength, 
 	int *ptruncated, SEA_VIEW *view, int try_as_keyword, Fl_Menu_Item *feature_item, const char *scan_word)
 {
-char *mnemo, *acc, *specname, *descr, *p, *seq;
-int length, frame, gencode, rank, type, pext, num, next, list1, matchinglist, count, err;
-static char line[500];
-
-mnemo = raa_getattributes(raa, id, &rank, &length, &frame, &gencode, &acc, &descr, &specname, 
-						  feature_item == NULL ? &seq : NULL);
-if(mnemo == NULL) {
-	if(try_as_keyword) {
-		return (import_one_keyword(raa, id, use_spec_name, ptruncated, view, 
-								   feature_item, scan_word) ? NULL : (char *)id);
-		}
-	else return NULL;
-	}
-if(feature_item != NULL) {
-	if(scan_word != NULL) {
-		sprintf(line, "n=%s and t=%s", mnemo, feature_item->label());
-		err = raa_proc_query(raa, line, NULL, (char *)"mylist", &list1, &count, NULL, NULL);
-		if(err || count == 0) return NULL;
-		matchinglist = scan_list(raa, list1, scan_word, feature_item->label() );
-		if(matchinglist == 0) return NULL; 
-		racnuc_fetch_file_or_list(NULL, matchinglist, use_spec_name, raa, view);
-		return (char *)"OK";
-		}
-	else {
-		mnemo = raa_readsub(raa, rank, NULL, &type, &pext, NULL, NULL, NULL, NULL);
-		int desired_type = (int)feature_item->argument();
-		if(type != desired_type ) {
-			next = -pext;
-			while(next > 0) {
-				next = raa_readlng(raa, next);
-				for (num = 0; num < raa->SUBINLNG; num++) {
-					rank = raa->rlng_buffer->sub[num];
-					if(rank == 0) break;
-					mnemo = raa_readsub(raa, rank, NULL, &type, NULL, NULL, NULL, NULL, NULL);
-					if(type == desired_type) break; 
-					}
-				if(type == desired_type) break; 
-				}
-			if(type != desired_type)  return NULL;
-			}
-		}
-	mnemo = raa_getattributes(raa, mnemo, NULL, &length, &frame, &gencode, &acc, &descr, &specname, &seq);
-	}
-gencode = get_ncbi_gc_number(gencode);
-if(frame == 1) {
-	seq -= 2; /* this terrible thing is possible after raa_getattributes */
-	length += 2;
-	*seq = '-'; *(seq + 1) = '-';
-	}
-else if(frame == 2) {
-	seq -= 1; length += 1;
-	*seq = '-'; 
-	}
-add_seq_to_align(view, use_spec_name ? specname : mnemo, seq, length);
-*plength = length;
-if(view->comments == NULL) view->comments = (char **)calloc(view->tot_seqs, sizeof(char *));
-p = view->comments[view->tot_seqs-1];
-*line = 0;
-if(p != NULL && strcmp(p, ";\n") != 0) strcpy(line, p);
-if(p != NULL) free(p);
-p = strchr(descr, ' '); /* skip 1st word (name) from descr */
-if(p != NULL) p++; else p = descr;
-sprintf(line + strlen(line), ";%s\n", p);
-p = line + strlen(line);
-if(use_spec_name) 
-	sprintf(p, ";Name=%s\n;Acc=%s\n", mnemo, acc);
-else 
-	sprintf(p, ";/organism=\"%s\"\n;Acc=%s\n", specname, acc);
-if(frame != 0 && strstr(line, "/codon_start=") == NULL) sprintf(line + strlen(line), 
-	";/codon_start=%d\n", frame + 1);
+  char *mnemo, *acc, *specname, *descr, *p, *seq;
+  int length, frame, gencode, rank, type, pext, num, next, list1, matchinglist, count, err;
+  static char line[500];
+  
+  mnemo = raa_getattributes(raa, id, &rank, &length, &frame, &gencode, &acc, &descr, &specname,
+                            feature_item == NULL ? &seq : NULL);
+  if(mnemo == NULL) {
+    if(try_as_keyword) {
+      return (import_one_keyword(raa, id, use_spec_name, ptruncated, view,
+                                 feature_item, scan_word) ? NULL : (char *)id);
+    }
+    else return NULL;
+  }
+  if(feature_item != NULL) {
+    if(scan_word != NULL) {
+      snprintf(line, sizeof(line), "n=%s and t=%s", mnemo, feature_item->label());
+      err = raa_proc_query(raa, line, NULL, (char *)"mylist", &list1, &count, NULL, NULL);
+      if(err || count == 0) return NULL;
+      matchinglist = scan_list(raa, list1, scan_word, feature_item->label() );
+      if(matchinglist == 0) return NULL;
+      racnuc_fetch_file_or_list(NULL, matchinglist, use_spec_name, raa, view);
+      return (char *)"OK";
+    }
+    else {
+      mnemo = raa_readsub(raa, rank, NULL, &type, &pext, NULL, NULL, NULL, NULL);
+      int desired_type = (int)feature_item->argument();
+      if(type != desired_type ) {
+        next = -pext;
+        while(next > 0) {
+          next = raa_readlng(raa, next);
+          for (num = 0; num < raa->SUBINLNG; num++) {
+            rank = raa->rlng_buffer->sub[num];
+            if(rank == 0) break;
+            mnemo = raa_readsub(raa, rank, NULL, &type, NULL, NULL, NULL, NULL, NULL);
+            if(type == desired_type) break;
+          }
+          if(type == desired_type) break;
+        }
+        if(type != desired_type)  return NULL;
+      }
+    }
+    mnemo = raa_getattributes(raa, mnemo, NULL, &length, &frame, &gencode, &acc, &descr, &specname, &seq);
+  }
+  gencode = get_ncbi_gc_number(gencode);
+  if(frame == 1) {
+    seq -= 2; /* this terrible thing is possible after raa_getattributes */
+    length += 2;
+    *seq = '-'; *(seq + 1) = '-';
+  }
+  else if(frame == 2) {
+    seq -= 1; length += 1;
+    *seq = '-';
+  }
+  add_seq_to_align(view, use_spec_name ? specname : mnemo, seq, length);
+  *plength = length;
+  if(view->comments == NULL) view->comments = (char **)calloc(view->tot_seqs, sizeof(char *));
+  p = view->comments[view->tot_seqs-1];
+  *line = 0;
+  if(p != NULL && strcmp(p, ";\n") != 0) strcpy(line, p);
+  if(p != NULL) free(p);
+  p = strchr(descr, ' '); /* skip 1st word (name) from descr */
+  if(p != NULL) p++; else p = descr;
+  snprintf(line + strlen(line), strlen(p)+3, ";%s\n", p);
+  p = line + strlen(line);
+  if(use_spec_name)
+    snprintf(p, 1000, ";Name=%s\n;Acc=%s\n", mnemo, acc);
+  else
+    snprintf(p, 1000, ";/organism=\"%s\"\n;Acc=%s\n", specname, acc);
+  if(frame != 0 && strstr(line, "/codon_start=") == NULL) {
+    int lline = sizeof(line) - strlen(line);
+    snprintf(line + strlen(line), lline, ";/codon_start=%d\n", frame + 1);
+  }
 int l = strlen(line);
 p = (char *)malloc(l + 1);
 if(p != NULL) strcpy(p, line);
@@ -594,9 +596,10 @@ int import_one_keyword(raa_db_access *raa, const char *keyword, int use_spec_nam
 	int numlist, err;
 	char query[WIDTH_MAX + 50];
 	
-	sprintf(query, "k=%s", keyword);
+	snprintf(query, sizeof(query), "k=%s", keyword);
 	if(feature_item != NULL) {
-		sprintf(query + strlen(query), " and t=%s", feature_item->label());
+		snprintf(query + strlen(query), sizeof(query)-strlen(query),
+                         " and t=%s", feature_item->label());
 		}
 	err = raa_proc_query(raa, query, NULL, (char *)"bykeyword", &numlist, NULL, NULL, NULL);
 	if(err) return 1;
@@ -614,7 +617,7 @@ static int scan_list(raa_db_access *raa, int mylist, const char *scan_word, cons
 {
 	int err, matchinglist;
 	char line[50], *p;
-	sprintf(line, "prep_getannots&nl=1\n%s|%s\n", raa->embl ? "FT" : "FEATURES", feature_name);
+	snprintf(line, sizeof(line), "prep_getannots&nl=1\n%s|%s\n", raa->embl ? "FT" : "FEATURES", feature_name);
 	sock_fputs(raa, line);
 	p = read_sock(raa);
 	if(strncmp(p, "code=0", 6) != 0) return 0;
