@@ -7,7 +7,7 @@
 #else
 #include <FL/x.H>
 #endif
-#ifdef WIN32
+#ifdef _WIN32
 #include <wchar.h>
 /*extern "C" {
   int _wsystem(const wchar_t *command );
@@ -249,10 +249,10 @@ int create_gblocks_mask(SEA_VIEW *view, region *maregion, int no_gui=false, int
   list_segments *segment, *previous;
   void (*alert)(const char*,...) = (no_gui ? Fl::fatal : fl_alert);
   
-#ifdef WIN32
+#ifdef _WIN32
 #define GBLOCKS_NAME "Gblocks.exe"
-#elif defined(__APPLE__)
-  const char  *GBLOCKS_NAME = (fl_mac_os_version >= 101400 ? "Gblocks_x86_64" : "Gblocks_ppc_i386");
+#elif defined(FLTK_COCOA_PLATFORM)
+  const char  *GBLOCKS_NAME = "Gblocks";
 #else
 #define GBLOCKS_NAME "Gblocks"
 #endif
@@ -260,7 +260,7 @@ int create_gblocks_mask(SEA_VIEW *view, region *maregion, int no_gui=false, int
   
   if (!q) {
     alert("Program Gblocks not found."
-#if !(defined(WIN32) || defined(__APPLE__))
+#if !(defined(_WIN32) || defined(FLTK_COCOA_PLATFORM))
     "\nTo use Gblocks, download it from http://molevol.cmima.csic.es/castresana/Gblocks.html\n"
     "and put it in a directory of your PATH"
 #endif
@@ -272,11 +272,11 @@ int create_gblocks_mask(SEA_VIEW *view, region *maregion, int no_gui=false, int
   p = create_tmp_filename();
   if(p == NULL) return 1;
   strcpy(base_fname, p);
-  sprintf(fname, "%s.fst", base_fname);
+  snprintf(fname, PATH_MAX, "%s.fst", base_fname);
   char **newnames = new char*[view->tot_seqs];
   for (int i = 0; i < view->tot_seqs; i++) {
     newnames[i] = new char[15];
-    sprintf(newnames[i], "Seq_%d", i);
+    snprintf(newnames[i], 15, "Seq_%d", i);
     }
   status = save_fasta_file(fname, view->sequence, NULL,
 		      newnames, view->tot_seqs, view->each_length, NULL,
@@ -288,12 +288,13 @@ int create_gblocks_mask(SEA_VIEW *view, region *maregion, int no_gui=false, int
     delete_tmp_filename(base_fname);
     return 1;
     }
-  sprintf(cmd, "\"%s\" \"%s\" -p=s -t=%c", q, fname, view->protein?'p':'d');
+  snprintf(cmd, sizeof(cmd), "\"%s\" \"%s\" -p=s -t=%c", q, fname, view->protein?'p':'d');
   if (b5_val) strcat(cmd, " -b5=h");
   if (b4_val) strcat(cmd, " -b4=5");
   if (b3_val) strcat(cmd, " -b3=4");
-  if (b2_val) sprintf(cmd + strlen(cmd), " -b2=%d", view->tot_seqs/2 + 1);
-#ifdef WIN32
+  if (b2_val) snprintf(cmd + strlen(cmd), sizeof(cmd)-strlen(cmd), " -b2=%d",
+                       view->tot_seqs/2 + 1);
+#ifdef _WIN32
   //conversion of utf-8 cmd into a WCHAR string
   int wlen = MultiByteToWideChar(CP_UTF8, 0, cmd, -1, NULL, 0);
   WCHAR *wcmd = new WCHAR[wlen];
@@ -312,7 +313,7 @@ int create_gblocks_mask(SEA_VIEW *view, region *maregion, int no_gui=false, int
   strcat(cmd, " > /dev/null");
   system(cmd);
 #endif
-  sprintf(fname, "%s.fst-gb.txts", base_fname);
+  snprintf(fname, PATH_MAX, "%s.fst-gb.txts", base_fname);
   in = fopen(fname, "r");
   if (in == NULL) status = 1;
   if (!status) {
