@@ -13,7 +13,7 @@ extern void *check_alloc(int nbrelt, int sizelt);
 void bydefault_aagroups(){
   int i;
   
-  sprintf(aalist, "EDQNHRKILMVAPSGTFYWC");
+  snprintf(aalist, 30, "EDQNHRKILMVAPSGTFYWC");
   for(i=0;i<7;i++) aagroup[i]=0;
   for(;i<11;i++) aagroup[i]=1;
   for(;i<16;i++) aagroup[i]=2;
@@ -372,8 +372,8 @@ void geni_act(SEA_VIEW *view)
   int nbseq = view->tot_seqs;
   
   bydefault_aagroups();
-  
-  text=(char*)check_alloc(10000, sizeof(char));
+  int ltext = 10000;
+  text = (char*)check_alloc(ltext, sizeof(char));
   
   nb=lgtot=0;
   selected=(int*)check_alloc(lgseq, sizeof(int));
@@ -559,9 +559,9 @@ void geni_act(SEA_VIEW *view)
   b->callback(save_stat_cb, ml);
   Fl_Return_Button *ok = new Fl_Return_Button(win->w() - 55 , win->h() - 23, 50, 20, "OK");
 
-  if(view->tot_sel_seqs == 0) sprintf(text, "%d species\n", nb);
+  if(view->tot_sel_seqs == 0) snprintf(text, ltext, "%d species\n", nb);
   else {
-    sprintf(text, "%d selected species\n", nb);
+    snprintf(text, ltext, "%d selected species\n", nb);
   }
   if(view->tot_sel_seqs > 0 && nb<=20){
     for(i=0;i<view->tot_seqs;i++){
@@ -572,96 +572,103 @@ void geni_act(SEA_VIEW *view)
     strcat(text, "\n");
   }
   p = text + strlen(text);
-  sprintf(p, "\n%d selected sites\n", lgtot);
-  p += strlen(p);
+  ltext -= strlen(text);
+  snprintf(p, ltext, "\n%d selected sites\n", lgtot);
+  p += strlen(p); ltext -= strlen(p);
   if(view->protein)
-    sprintf(p, "    including    %d complete (no gaps, no X)\n", lg);
+    snprintf(p, ltext, "    including    %d complete (no gaps, no X)\n", lg);
   else
-    sprintf(p, "    including    %d complete (no gaps, no N)\n", lg);
-  p += strlen(p);
+    snprintf(p, ltext, "    including    %d complete (no gaps, no N)\n", lg);
+  ltext -= strlen(p); p += strlen(p);
   if(nb>=2 && lg!=0){
-    sprintf(p, "    including    %d variable (%.1f%% of complete)\n", lgvar, (double)lgvar*100/lg);
-    p += strlen(p);
+    snprintf(p, ltext, "    including    %d variable (%.1f%% of complete)\n", lgvar, (double)lgvar*100/lg);
+    ltext -= strlen(p); p += strlen(p);
     if(nb>=4){
-      sprintf(p, "    including    %d informative (%.1f%% of complete)\n", lginfo, (double)lginfo*100/lg);
-      p += strlen(p);
+      snprintf(p, ltext, "    including    %d informative (%.1f%% of complete)\n", lginfo, (double)lginfo*100/lg);
+      ltext -= strlen(p); p += strlen(p);
     }
   }
   if(view->protein){
     int k;
-    sprintf(p, "\nAMINOACID COMPOSITION (all sites) :\n");
-    p += strlen(p);
+    snprintf(p, ltext, "\nAMINOACID COMPOSITION (all sites) :\n");
+    ltext -= strlen(p); p += strlen(p);
     j=0; 
     for(i=0;i<nbaagroup;i++){
-      sprintf(p, "\n\nGroup %d : %.1f%%", i+1, compgroupall[i]);
-      p += strlen(p);
+      snprintf(p, ltext, "\n\nGroup %d : %.1f%%", i+1, compgroupall[i]);
+      ltext -= strlen(p); p += strlen(p);
       k = 0;
       while(aagroup[j]==i){
 	if(k++ % 3 == 0) {
-	  sprintf(p, "\n    "); p += strlen(p);
+	  snprintf(p, ltext, "\n    ");
+          ltext -= strlen(p); p += strlen(p);
 	  }
-	sprintf(p, "%c : %.1f     ", aalist[j], compall[j]);
-	p += strlen(p);
+	snprintf(p, ltext, "%c : %.1f     ", aalist[j], compall[j]);
+        ltext -= strlen(p); p += strlen(p);
 	j++;
       }
-      if(k % 3 != 0) sprintf(p++, "\n");
+      if(k % 3 != 0) { snprintf(p++, ltext, "\n"); ltext--; }
     }
     if(j!=nbaa){
-      sprintf(p, "\n\nOthers : \n");
-      p += strlen(p);
+      snprintf(p, ltext, "\n\nOthers : \n");
+      ltext -= strlen(p); p += strlen(p);
       while(aalist[j]){
-	sprintf(p, "%c : %.1f     ", aalist[j], compall[j]);
-	p += strlen(p);
-	sprintf(p++, "\n");
+	snprintf(p, ltext, "%c : %.1f     ", aalist[j], compall[j]);
+        ltext -= strlen(p); p += strlen(p);
+        snprintf(p++, ltext, "\n"); ltext--;
 	j++;
       }
     }
   }
   else{
-    sprintf(p, "\nBASE COMPOSITION :\n");
-    p += strlen(p);
-    sprintf(p, "     All sites  :\t %.1f%% A   %.1f%% C   %.1f%% G   %.1f%% T\n", compall[0], compall[1], compall[2], compall[3]);
-    p += strlen(p);
+    snprintf(p, ltext, "\nBASE COMPOSITION :\n");
+    ltext -= strlen(p); p += strlen(p);
+    snprintf(p, ltext, "     All sites  :\t %.1f%% A   %.1f%% C   %.1f%% G   %.1f%% T\n", compall[0], compall[1], compall[2], compall[3]);
+    ltext -= strlen(p); p += strlen(p);
     if(nb>1 && lg!=0){
-      sprintf(p, "     Complete sites only :\n");
-      p += strlen(p);
-      sprintf(p, "                                Minimum                   Maximum:\n");
-      p += strlen(p);
+      snprintf(p, ltext, "     Complete sites only :\n");
+      ltext -= strlen(p); p += strlen(p);
+      snprintf(p, ltext, "                                Minimum                   Maximum:\n");
+      ltext -= strlen(p); p += strlen(p);
       for(i=0;i<4;i++){
-        sprintf(p, "     %c : %.1f %%    ", nt[i], compcomp[i]);
-	p += strlen(p);
-        sprintf(p, "%.1f%% (%s)     ", min[i], minname[i]);
- 	p += strlen(p);
-        sprintf(p, "%.1f%% (%s)\n", max[i], maxname[i]);
-	p += strlen(p);
+        snprintf(p, ltext, "     %c : %.1f %%    ", nt[i], compcomp[i]);
+        ltext -= strlen(p); p += strlen(p);
+        snprintf(p, ltext, "%.1f%% (%s)     ", min[i], minname[i]);
+        ltext -= strlen(p); p += strlen(p);
+        snprintf(p, ltext, "%.1f%% (%s)\n", max[i], maxname[i]);
+        ltext -= strlen(p); p += strlen(p);
       }
     }
   }
   
   if(!view->protein && nb>1 && lg!=0){
-    sprintf(p, "\nOBSERVED CHANGES (complete sites)\n"); p += strlen(p);
+    snprintf(p, ltext, "\nOBSERVED CHANGES (complete sites)\n");
+    ltext -= strlen(p); p += strlen(p);
     double PQratio = Qsum ? (double)Psum/Qsum : 0;
     if(nb>2)
-      sprintf(p, "Transition/transversion ratio : %.3f (mean over all sequence pairs)\n", PQratio);
+      snprintf(p, ltext, "Transition/transversion ratio : %.3f (mean over all sequence pairs)\n", PQratio);
     else
-      sprintf(p, "Transition/transversion ratio : %.3f\n", PQratio);
-    p += strlen(p);
+      snprintf(p, ltext, "Transition/transversion ratio : %.3f\n", PQratio);
+    ltext -= strlen(p); p += strlen(p);
     if(nb>2){
-      sprintf(p, "Minimum : %.3f (%s - %s, %d transitions, %d transversions)\n", titvmin, titvminname1, titvminname2, (int)Pmin, (int)Qmin);
-      p += strlen(p);
-      sprintf(p, "Maximum : %.3f (%s - %s, %d transitions, %d transversions)\n", titvmax, titvmaxname1, titvmaxname2, (int)Pmax, (int)Qmax);
-      //p += strlen(p);
+      snprintf(p, ltext, "Minimum : %.3f (%s - %s, %d transitions, %d transversions)\n", titvmin, titvminname1, titvminname2, (int)Pmin, (int)Qmin);
+      ltext -= strlen(p); p += strlen(p);
+      snprintf(p, ltext, "Maximum : %.3f (%s - %s, %d transitions, %d transversions)\n", titvmax, titvmaxname1, titvmaxname2, (int)Pmax, (int)Qmax);
+      //ltext -= strlen(p); p += strlen(p);
     }
     else {
-      sprintf(p, "Observed nucleotide pairs :\n"); p += strlen(p);
-      sprintf(p, "%35s%s\n"
-	         "%36s A     C     G     T\n", "", genname[1], ""); p += strlen(p);
+      strcpy(p, "Observed nucleotide pairs :\n");
+      ltext -= strlen(p); p += strlen(p);
+      snprintf(p, ltext, "%35s%s\n"
+	         "%36s A     C     G     T\n", "", genname[1], "");
+      ltext -= strlen(p); p += strlen(p);
       for(i=0;i<4;i++){
-	sprintf(p, "%30s %c", i==1 ? genname[0] : "", nt[i]); p += strlen(p);
+	snprintf(p, ltext, "%30s %c", i==1 ? genname[0] : "", nt[i]);
+        ltext -= strlen(p); p += strlen(p);
    	for(j=0;j<4;j++){
-	  sprintf(p, "%6d", (int)(freq[4*i+j]*lgtot)); p += strlen(p);
+	  snprintf(p, ltext, "%6d", (int)(freq[4*i+j]*lgtot));
+          ltext -= strlen(p); p += strlen(p);
 	}
-	*p++ = '\n';
+        *p++ = '\n'; ltext--;
       }
     }
   } 
