@@ -1,6 +1,24 @@
 #ifndef FL_SVG_GRAPHICS_DRIVER_H
 #define FL_SVG_GRAPHICS_DRIVER_H
 
+#include <FL/Enumerations.H>
+
+#if 10*FL_MAJOR_VERSION + FL_MINOR_VERSION >= 14
+
+#include <FL/Fl_SVG_File_Surface.H>
+
+class SVG_File_Surface : public Fl_SVG_File_Surface  {
+  int W, H;
+public:
+  SVG_File_Surface(int width, int height, FILE *f, bool use_pdf_width = false) :
+    Fl_SVG_File_Surface(width, height, f) , W(width), H(height) {}
+  int width() { return W; }
+  int height() { return H;  }
+  void end() {}
+};
+
+#else
+
 #include <stdio.h>
 #include <FL/Fl_Device.H>
 #ifndef NO_PDF
@@ -43,7 +61,7 @@ protected:
   int height() ;
   int descent() ;
   
-#if 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION + FL_PATCH_VERSION >= 140
+#if 10*FL_MAJOR_VERSION + FL_MINOR_VERSION >= 14
   void push_clip(int x, int y, int w, int h) {}
   void pop_clip(){}
   void xyline(int x, int y, int x1){}
@@ -73,8 +91,6 @@ protected:
   virtual void circle(double x, double y, double r) {}
   virtual void arc(int x, int y, int w, int h, double a1, double a2) {}
   virtual void pie(int x, int y, int w, int h, double a1, double a2) {}
-  virtual Fl_Bitmask create_bitmask(int w, int h, const uchar *array) {return 0;}
-  virtual void delete_bitmask(Fl_Bitmask bm) {}
 #endif
 };
 
@@ -108,3 +124,4 @@ public:
 
 #endif // FL_SVG_GRAPHICS_DRIVER_H
 
+#endif // FLTK ≥ 1.4
