@@ -1,3 +1,5 @@
+#include <FL/Enumerations.H>
+#if 10*FL_MAJOR_VERSION + FL_MINOR_VERSION >= 14
 #include "treerecs_draw.h"
 
 #include <sys/stat.h>
@@ -25,7 +27,7 @@ extern void delete_tmp_filename(const char *base_fname);
 int treerecs_run_interrupted;
 
 // Directory separator
-#ifdef WIN32
+#ifdef _WIN32
   static const char preferred_separator = '\\';
 #else
   static const char preferred_separator = '/';
@@ -455,7 +457,7 @@ void treerecs_dialog(Fl_Widget *view, void* data)
 
     w->hide();
 
-    int status =
+    /*int status =*/
         run_external_prog_in_pseudoterm((char*) treerecs_command.c_str(),
                                         NULL,
                                         "Treerecs");
@@ -489,8 +491,7 @@ void treerecs_dialog(Fl_Widget *view, void* data)
           perror("Invalid svg filename.\n");
         }
 
-        Fl_Window* recphylowml_window =
-            svgdraw(svg_file_path,
+        /*Fl_Window* recphylowml_window =*/ svgdraw(svg_file_path,
                 main_output_file_path,
                 "Full-reconciliation view");
       }
@@ -918,8 +919,8 @@ Fl_Window * svgdraw(const string& svg_file_path,
   // Add text box to print a summary of events in the reconciled tree.
   Fl_Box* text_box = new Fl_Box(25, menu->y() + menu->h() + 10, svg_width/3, 20);
   char* text_box_message = (char*)malloc(sizeof(char)*1024);
-  sprintf(
-      text_box_message
+  snprintf(
+      text_box_message, 1024
       , "Total cost of the reconciliation = %.1f, duplications = %d, losses = %d"
       , view_data->total_cost
       , view_data->duplication_number
@@ -1044,3 +1045,5 @@ void save_recphyloxml_file_callback(Fl_Widget *ob, void *data) {
     copyfile(filename, svg_data->rpx_fname);
   }
 }
+
+#endif // 10*FL_MAJOR_VERSION + FL_MINOR_VERSION >= 14
