@@ -1,4 +1,4 @@
-#ifdef WIN32
+#ifdef _WIN32
 #include <windows.h>
 #else
 #include <sys/times.h>
@@ -15,7 +15,7 @@
 #include <FL/Fl_Value_Slider.H>
 #include <FL/Fl.H>
 #include <FL/fl_ask.H>
-#ifdef __APPLE__
+#ifdef FLTK_COCOA_PLATFORM
 #include <FL/x.H> // for fl_mac_os_version
 #endif
 
@@ -281,7 +281,7 @@ void distance_method_dialog(SEA_VIEW *view)
 		replicates = new Fl_Int_Input(bootstrap->x() + bootstrap->w() + 5, y, 100, 20, "# of replicates");
 		replicates->align(FL_ALIGN_TOP|FL_ALIGN_CENTER);
 		char tmp[10];
-		sprintf(tmp, "%d", def_replicates);
+		snprintf(tmp, 10, "%d", def_replicates);
 		replicates->value(tmp);
 
 		compute_tbe = new Fl_Check_Button(3, bootstrap->y() + bootstrap->h() + 5, 280, 20, "Transfer Bootstrap Expectation method");
@@ -389,12 +389,12 @@ void distance_method_dialog(SEA_VIEW *view)
 	    char *q = (char*)strchr(n, '.');
 	    if (q) *q = 0;
 	    title = new char[strlen(n) + 12];
-	    sprintf(title, "%s-%s", n, choice);
+	    snprintf(title, strlen(n) + 12, "%s-%s", n, choice);
 	    if (q) *q = '.';
 	  }
     Fl_Window *treew = NULL;
 	  if (tree) treew = treedraw(tree, view, n || usertree->value() ? title:choice, FALSE);
-#if !defined(__APPLE__)
+#if !defined(FLTK_COCOA_PLATFORM)
     if (keep_b_trees->value() && treew) {
       treew->position(treew->x() + 40, treew->y());
     }
@@ -509,9 +509,11 @@ char *run_distance_method(SEA_VIEW *view, int distkind, int remove_all_gaps, int
 		p = least_squares_brl(p, phyml_seqs->n_otu, phyml_mat->dist, usednames);
 		if(view->tot_sel_seqs > 0) free(usednames);
 		if(p != NULL) {
-			display_tree = (char *)malloc(strlen(p) + strlen(distance_name) + 60);
-			sprintf(display_tree, "[User-tree w/ least-squares br lengths, %d sites %s]%s", 
-					phyml_seqs->clean_len, distance_name, p);
+                        int ldisp = strlen(p) + strlen(distance_name) + 60;
+			display_tree = (char *)malloc(ldisp);
+			snprintf(display_tree, ldisp,
+                              "[User-tree w/ least-squares br lengths, %d sites %s]%s",
+                              phyml_seqs->clean_len, distance_name, p);
 			free(p);
 			if (box) box->window()->hide();//necessary under X11 so tree is in foreground
 			}
@@ -528,8 +530,9 @@ char *run_distance_method(SEA_VIEW *view, int distkind, int remove_all_gaps, int
 	phyml_mat->method = use_bionj; //0:NJ 1:BioNJ
 	phyml_mat->tree = Make_Tree_From_Scratch(phyml_seqs->n_otu, phyml_seqs);
 	Bionj(phyml_mat);
-	sprintf(tree_label, "%s %d sites %s", use_bionj ? "BioNJ" : "NJ",
-		phyml_seqs->clean_len, distance_name);
+	snprintf(tree_label, sizeof(tree_label), "%s %d sites %s",
+                 use_bionj ? "BioNJ" : "NJ",
+		 phyml_seqs->clean_len, distance_name);
 	if (use_bootstrap) {
 		char *full_tree = Write_Tree(phyml_mat->tree);
 		Free_Tree(phyml_mat->tree);
@@ -572,7 +575,7 @@ char *run_distance_method(SEA_VIEW *view, int distkind, int remove_all_gaps, int
 				total += process_one_replicate(one_replicate_tree, 1.);
 				free(one_replicate_tree);
 				char newbox[20];
-				sprintf(newbox,"Count: %d", total);
+				snprintf(newbox, 20,"Count: %d", total);
 				if (box) {
 				  box->label(newbox);
 				  box->redraw();
@@ -582,7 +585,9 @@ char *run_distance_method(SEA_VIEW *view, int distkind, int remove_all_gaps, int
 		}
 		if(total > 0) {
 			display_tree = finish_add_bootstrap(total);
-			sprintf(tree_label + strlen(tree_label), " %d repl.%s", total, compute_tbe ? " (TBE)" : "" );
+			snprintf(tree_label + strlen(tree_label),
+                                sizeof(tree_label) - strlen(tree_label),
+                                " %d repl.%s", total, compute_tbe ? " (TBE)" : "" );
 			}
 		else display_tree = NULL;
 	}
@@ -603,8 +608,9 @@ char *run_distance_method(SEA_VIEW *view, int distkind, int remove_all_gaps, int
 	  display_tree=TBE_Compute(display_tree,bootstrap_trees);
 	}
 	//add label to tree
-	char *tree = (char *)malloc(strlen(tree_label) + strlen(display_tree) + 4);
-	sprintf(tree, "[%s] %s", tree_label, display_tree);
+        int ltree = strlen(tree_label) + strlen(display_tree) + 4;
+	char *tree = (char *)malloc(ltree);
+	snprintf(tree, ltree, "[%s] %s", tree_label, display_tree);
 	free(display_tree);
 	if (box) box->window()->hide();//necessary under X11 so tree is in foreground
   if (bootstrap_trees && keep_b_trees) {
@@ -778,11 +784,11 @@ void phyml_dialog(SEA_VIEW *view)
 	static int first = TRUE;
 	if(first) {
 		char *p, *q;
-#if defined(__APPLE__)
+#if defined(FLTK_COCOA_PLATFORM)
 #  ifdef __ppc__
           p = (char*)"phyml_3.0_universal";
 #  else
-          p = (char*)(fl_mac_os_version < 100800 ? "phyml_3.0_universal" : "PhyML-3.1_macOS-MountainLion");
+          p = (char*)(fl_mac_os_version < 100900 ? "phyml_3.0_universal" : "phyml");
 #  endif // __ppc__
           if ((q = get_full_path(p)) == NULL) {
             fl_message("Warning: PhyML executable not found. Please, download the seaview macOS application again.");
@@ -790,7 +796,7 @@ void phyml_dialog(SEA_VIEW *view)
           }
 #else
 		p = get_res_value("phyml",
-#  ifdef WIN32
+#  ifdef _WIN32
 					"PhyML-3.1_win32.exe"
 #  elif defined(sparc)
 						  "phyml_3.0_sparc"
@@ -803,7 +809,7 @@ void phyml_dialog(SEA_VIEW *view)
 #      endif // __i386__
 #    endif // PHYMLNAME
 					PHYMLNAME
-#  endif // WIN32
+#  endif // _WIN32
 		);
 #if defined(__linux__)
 	  if ((q = get_full_path(p)) == NULL) p = (char*)"phyml";
@@ -820,10 +826,10 @@ void phyml_dialog(SEA_VIEW *view)
 			set_res_value("phyml", q);
 			save_resources();
 			}
-#endif // __APPLE__
+#endif // FLTK_COCOA_PLATFORM
 		first = FALSE;
 		phyml_path = (char *)malloc(strlen(q) + 3);
-		sprintf(phyml_path, "\"%s\"", q);
+		snprintf(phyml_path, strlen(q) + 3, "\"%s\"", q);
 		}
 	return_window *w = new return_window(270,130, "PhyML options");
 	w->set_modal();
@@ -1014,7 +1020,7 @@ void phyml_dialog(SEA_VIEW *view)
 	ok->callback(run_phyml_callback, view);
   u_quiet = new Fl_Check_Button(cancel->x() + cancel->w() + 40, y, 65, 20, "Quiet");
   u_quiet->value(0);
-#ifndef WIN32
+#ifndef _WIN32
   //u_quiet->hide();
 #endif
 	w->end();
@@ -1104,7 +1110,7 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
     if(view->tot_sel_seqs > 0 && !view->sel_seqs[i]) continue;
     tmpnames[i] = (char *)malloc(15);
     truenames[i] = strdup(view->seqname[i]);
-    sprintf(tmpnames[i], "Seq%d_", i);
+    snprintf(tmpnames[i], 15, "Seq%d_", i);
     length = FL_max(length, (int)strlen(tmpnames[i]));
     }
   status = save_phylip_file(input, tmpseqs,
@@ -1136,7 +1142,7 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
   strcpy(modelname, mymodel->mvalue()->label());
   //build command line
   args = (char *)malloc(1000);
-  sprintf(args, "%s -d %s -m %s -b %d -v %s -c %d -a %s",
+  snprintf(args, 1000, "%s -d %s -m %s -b %d -v %s -c %d -a %s",
 		  phyml_path, view->protein?"aa":"nt", modelname, replicates, invar, cats, alpha); 
   if( (!view->protein) && 
   (strcmp(modelname,"K80")==0 || strcmp(modelname,"HKY85")==0 || strcmp(modelname,"F84")==0 || strcmp(modelname,"TN93")==0) ) {
@@ -1144,7 +1150,7 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
 	  strcat(args, " -t e");
 	  }
   else {
-	  sprintf(args + strlen(args), " -t %s", r_val->value());
+	  snprintf(args + strlen(args), 1000-strlen(args), " -t %s", r_val->value());
 	  }
   }
   if( (view->protein) || 
@@ -1172,31 +1178,33 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
 		  fl_alert("Names in starting tree and alignment don't match.\nStarting tree will be ignored.");
 		  }
 	  else {
-		  char tmp[PATH_MAX];
-		  sprintf(tmp, "%s.startingtree", base_fname);
+		   char tmp[PATH_MAX];
+		   snprintf(tmp, PATH_MAX, "%s.startingtree", base_fname);
 		   FILE *out = fopen(tmp, "w");
 		   fputs(tree, out);
 		   free(tree);
 		   fclose(out);
-		   sprintf(args + strlen(args), " -u \"%s\"", tmp);
+		   snprintf(args + strlen(args), 1000-strlen(args), " -u \"%s\"", tmp);
 		  }
    }
   if(u_random->value()) {
-		  sprintf(args + strlen(args), " --rand_start --n_rand_starts %d", atoi(u_random_count->value()));
+		  snprintf(args + strlen(args), 1000-strlen(args),
+                           " --rand_start --n_rand_starts %d",
+                           atoi(u_random_count->value()));
 		  }
   //finish with (long) input filename
-  sprintf(args + strlen(args), " -i \"%s\"", input);
+  snprintf(args + strlen(args), 1000-strlen(args), " -i \"%s\"", input);
   ob->window()->hide(); //deletion of this window should be done totally at the end of this callback
   status = run_external_prog_in_pseudoterm(args, NULL, "tree-building");
   free(args);
-  sprintf(input, "%s.phy_phyml_stats.txt", base_fname);
+  snprintf(input, PATH_MAX, "%s.phy_phyml_stats.txt", base_fname);
   in = fopen(input, "r");
   if (in == NULL) {
-    sprintf(input, "%s.phy_phyml_stat.txt", base_fname);
+    snprintf(input, PATH_MAX, "%s.phy_phyml_stat.txt", base_fname);
     in = fopen(input, "r");
     }
   if (in == NULL) {
-    sprintf(input, "%s.phy_phyml_stats", base_fname);
+    snprintf(input, PATH_MAX, "%s.phy_phyml_stats", base_fname);
     in = fopen(input, "r");
     }
   logL = 0;
@@ -1210,10 +1218,10 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
 		  }
 	  fclose(in);
 	  }
-  sprintf(input, "%s.phy_phyml_tree.txt", base_fname);
+  snprintf(input, PATH_MAX, "%s.phy_phyml_tree.txt", base_fname);
   in = fopen(input, "r");
   if (in == NULL) {
-    sprintf(input, "%s.phy_phyml_tree", base_fname);
+    snprintf(input, PATH_MAX, "%s.phy_phyml_tree", base_fname);
     in = fopen(input, "r");
     }
   if( status != 0 || in == NULL ) {
@@ -1236,10 +1244,10 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
     //process bootstrap trees
     char *bootstrap_trees = NULL;
     if (replicates > 0) {
-      sprintf(input, "%s.phy_phyml_boot_stats.txt", base_fname);
+      snprintf(input, PATH_MAX, "%s.phy_phyml_boot_stats.txt", base_fname);
       in = fopen(input, "r");
       if (!in) {
-        sprintf(input, "%s.phy_phyml_boot_stats", base_fname);
+        snprintf(input, PATH_MAX, "%s.phy_phyml_boot_stats", base_fname);
         in = fopen(input, "r");
       }
       if (in) { // compute the true # of bootstrap replicates because parallelized phyML can compute a few more
@@ -1254,15 +1262,15 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
       }
     }
     if (replicates > 0 && (b_keep_trees->value() || b_tbe->value())) {
-      sprintf(input, "%s.phy_phyml_boot_trees.txt", base_fname);
+      snprintf(input, PATH_MAX, "%s.phy_phyml_boot_trees.txt", base_fname);
       in = fopen(input, "r");
       if (!in) {
-      	sprintf(input, "%s.phy_phyml_boot_trees", base_fname);
+      	snprintf(input, PATH_MAX, "%s.phy_phyml_boot_trees", base_fname);
       	in = fopen(input, "r");
       }
       if (in) {
         FILE *out = NULL;
-        sprintf(input, "%s.phy_phyml_boot_trees_truename.txt", base_fname);
+        snprintf(input, PATH_MAX, "%s.phy_phyml_boot_trees_truename.txt", base_fname);
         out = fopen(input, "w");
         long l = 1000;
         while (out) { // for all bootstrap trees
@@ -1321,27 +1329,37 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
 	  
 	  //assemble tree description
 	  char tree_label[100];
-	  sprintf(tree_label, "PhyML ln(L)=%.1f %d sites %s", logL, seqlen, modelname);
+	  snprintf(tree_label, 100, "PhyML ln(L)=%.1f %d sites %s", logL, seqlen, modelname);
 	  if(replicates > 0) {
-      sprintf(tree_label + strlen(tree_label), " %d replic.", replicates);
+            snprintf(tree_label + strlen(tree_label), 100-strlen(tree_label),
+                     " %d replic.", replicates);
 	  }
-	  if(cats > 1) sprintf(tree_label + strlen(tree_label), " %d rate classes", cats);
+          if( cats > 1) {
+            snprintf(tree_label + strlen(tree_label), 100-strlen(tree_label),
+                     " %d rate classes", cats);
+          }
 	  if(user_tree) strcat(tree_label, " User-tree");
 	  //add label to tree
-	  char *tree = (char *)malloc(strlen(tree_label) + strlen(display_tree) + 4);
-	  sprintf(tree, "[%s] %s", tree_label, display_tree);
+          int ltree = strlen(tree_label) + strlen(display_tree) + 4;
+	  char *tree = (char *)malloc(ltree);
+	  snprintf(tree, ltree, "[%s] %s", tree_label, display_tree);
 	  free(display_tree);
     
     if (replicates > 0 && b_tbe->value()) {
       //assemble TBE tree description
       char tree_label_tbe[100];
-      sprintf(tree_label_tbe, "PhyML ln(L)=%.1f %d sites %s", logL, seqlen, modelname);
-      sprintf(tree_label_tbe + strlen(tree_label_tbe), " %d replic. (TBE)", replicates);
-      if(cats > 1) sprintf(tree_label_tbe + strlen(tree_label_tbe), " %d rate classes", cats);
+      snprintf(tree_label_tbe, 100, "PhyML ln(L)=%.1f %d sites %s", logL, seqlen, modelname);
+      snprintf(tree_label_tbe + strlen(tree_label_tbe), 100-strlen(tree_label_tbe),
+              " %d replic. (TBE)", replicates);
+      if (cats > 1) {
+        snprintf(tree_label_tbe + strlen(tree_label_tbe), 100-strlen(tree_label_tbe),
+                " %d rate classes", cats);
+      }
       if(user_tree) strcat(tree_label_tbe, " User-tree");
       //add label to tree
-      char *tree = (char *)malloc(strlen(tree_label_tbe) + strlen(display_tree_tbe) + 4);
-      sprintf(tree, "[%s] %s", tree_label_tbe, display_tree_tbe);
+      int ltree = strlen(tree_label_tbe) + strlen(display_tree_tbe) + 4;
+      char *tree = (char *)malloc(ltree);
+      snprintf(tree, ltree, "[%s] %s", tree_label_tbe, display_tree_tbe);
       free(display_tree_tbe);
       display_tree_tbe = tree;
     }
@@ -1353,7 +1371,7 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
 	      char *q = (char*)strchr(n, '.');
 	      if (q) *q = 0;
 	      title = new char[strlen(n) + 12];
-	      sprintf(title, "%s-%s", n, "PhyML_tree");
+	      snprintf(title, strlen(n) + 12, "%s-%s", n, "PhyML_tree");
 	      if (q) *q = '.';
 	    }
       Fl_Window *btreew=0, *treew=0;
@@ -1363,11 +1381,11 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
       if (replicates > 0 && b_tbe->value()) {
         const char *p = n ? title:"PhyML_tree";
         char *q = (char*)malloc(strlen(p) + 5);
-        sprintf(q, "%s_TBE", p);
+        snprintf(q, strlen(p) + 5, "%s_TBE", p);
         treedraw(display_tree_tbe, view, q, FALSE);
       }
 	    treew = treedraw(tree, view, n ? title:"PhyML_tree", FALSE);
-#if !defined(__APPLE__)
+#if !defined(FLTK_COCOA_PLATFORM)
       if (treew && btreew) treew->position(btreew->x() + 30, btreew->y() + 40);
 #endif
 	    delete[] title;
@@ -1506,7 +1524,7 @@ void free_after_view_to_allseq(allseq *phyml_seqs)
   unsigned seed;
   if(first) {
     first = FALSE;
-#ifdef WIN32
+#ifdef _WIN32
     SYSTEMTIME timing;
     GetSystemTime(&timing);
     seed = (unsigned)(timing.wMilliseconds + 1000*(timing.wSecond + 60*(timing.wMinute + 60*(timing.wHour + 24*timing.wDay))));
@@ -1525,7 +1543,7 @@ double next_random(void)
   unsigned seed;
   if (first) {
     first = FALSE;
-#ifdef WIN32
+#ifdef _WIN32
     SYSTEMTIME timing;
     GetSystemTime(&timing);
     seed = (unsigned)(timing.wMilliseconds + 1000*(timing.wSecond + 60*(timing.wMinute + 60*(timing.wHour + 24*timing.wDay))));
@@ -1537,7 +1555,7 @@ double next_random(void)
 #endif
   }
   
-#ifdef WIN32
+#ifdef _WIN32
   return rand() / (RAND_MAX +(double)1.);
 #else
   return random() / (RAND_MAX +(double)1.);
@@ -1680,7 +1698,7 @@ char *alrt_reformat(char *tree)
 			}
 		if(*q != ':' ) continue;
 		sscanf(p, "%f", &alrt);
-		sprintf(tmp, "%.2f", alrt);
+		snprintf(tmp, 20, "%.2f", alrt);
 		l = strlen(tmp);
 		if(l < q - p) { memset(p, ' ', q - p); memcpy(p, tmp, l); }
 		}
@@ -1706,7 +1724,7 @@ char *bootstrap_reformat(char *tree, int replicates)
 		pnew += p - next;
 		next = p;
 		sscanf(p, "%d", &count);
-		sprintf(pnew, "%d", (int)(100*count/float(replicates) + .5));
+		snprintf(pnew, 10, "%d", (int)(100*count/float(replicates) + .5));
 		pnew += strlen(pnew);
 		next = q;
 	}
@@ -2026,7 +2044,7 @@ char *add_equally_best(char *tree, char *all_best, int count)
     int rank = 0;
     while (count-- > 0) {
       r = strchr(p, '\n');
-      sprintf(q, "[equally best tree #%d]", ++rank);
+      snprintf(q, 30, "[equally best tree #%d]", ++rank);
       q += strlen(q);
       memcpy(q, p, r - p + 1);
       q += r-p+1;
@@ -2070,9 +2088,11 @@ static char *run_parsimony_method(SEA_VIEW *view, int nogaps, const char *gapsun
     if (tree) {
       final_tree = (char *)malloc(strlen(tree) + 200);
       char best[35] = "";
-      if (count_best > 1) sprintf(best, "consensus of %d best trees, ", count_best);
-      sprintf(final_tree, "[%s, bootstrap with %d replic., %d steps, %s%d sites (%d informative)%s]%s",
-	      *pprogname, replicates_done, steps, best, tmpallseqs->clean_len, info, gapsunknown, tree);
+      if (count_best > 1) snprintf(best, 35, "consensus of %d best trees, ", count_best);
+      snprintf(final_tree, strlen(tree) + 200,
+        "[%s, bootstrap with %d replic., %d steps, %s%d sites (%d informative)%s]%s",
+        *pprogname, replicates_done, steps, best, tmpallseqs->clean_len, info,
+        gapsunknown, tree);
     }
   }
   else if(user_tree) {
@@ -2099,8 +2119,9 @@ static char *run_parsimony_method(SEA_VIEW *view, int nogaps, const char *gapsun
       }
       else {
         final_tree = (char *)malloc(strlen(tree) + 150);
-        sprintf(final_tree, "[%s, user-tree, %d steps, %d sites (%d informative)%s]%s",
-                *pprogname, steps, tmpallseqs->clean_len, info, gapsunknown, tree);
+        snprintf(final_tree, strlen(tree) + 150,
+                 "[%s, user-tree, %d steps, %d sites (%d informative)%s]%s",
+                 *pprogname, steps, tmpallseqs->clean_len, info, gapsunknown, tree);
       }
     }
   }
@@ -2121,10 +2142,14 @@ static char *run_parsimony_method(SEA_VIEW *view, int nogaps, const char *gapsun
     if (tree) {
       char aux[30];
       final_tree = (char *)malloc(strlen(tree) + 150);
-      if (count > 1) sprintf(aux, " (%d%% consensus)", int(consensus_threshold*100 + 0.5));
+      if (count > 1) {
+        snprintf(aux, 30, " (%d%% consensus)", int(consensus_threshold*100 + 0.5));
+      }
       else *aux = 0;
-      sprintf(final_tree, "[%s, %d best trees%s, %d steps, %d sites (%d informative)%s]%s",
-	      *pprogname, count, aux, steps, tmpallseqs->clean_len, info, gapsunknown, tree);
+      snprintf(final_tree, strlen(tree) + 150,
+               "[%s, %d best trees%s, %d steps, %d sites (%d informative)%s]%s",
+	       *pprogname, count, aux, steps, tmpallseqs->clean_len, info, gapsunknown,
+               tree);
       if (count > 1) final_tree = add_equally_best(final_tree, all_best, count);
     }
   }
@@ -2250,7 +2275,7 @@ void parsimony_dialog(SEA_VIEW *view)
 	nogaps = w_nogaps->value();
 	char gapsunknown[25];
 	if(w_gapsunknown->value())
-	sprintf(gapsunknown, ", gaps treated as %c", (view->protein ? 'X' : 'N') );
+	snprintf(gapsunknown, 25, ", gaps treated as %c", (view->protein ? 'X' : 'N') );
 	else gapsunknown[0] = 0;
 	if(use_bootstrap) {
 		p = w_btrepl->value();
@@ -2282,7 +2307,7 @@ void parsimony_dialog(SEA_VIEW *view)
 	    char *q = (char*)strchr(n, '.');
 	    if (q) *q = 0;
 	    title = new char[strlen(n) + strlen(progname) + 2];
-	    sprintf(title, "%s-%s", n, progname);
+	    snprintf(title, strlen(n) + strlen(progname) + 2, "%s-%s", n, progname);
 	    if (q) *q = '.';
 	  }
     int tree_count = 0;
@@ -2295,8 +2320,11 @@ void parsimony_dialog(SEA_VIEW *view)
     if (tree_count == 0) tree_count = 1;
     Fl_Window *btreew = NULL;
     if (bootstrap_trees) btreew = treedraw(bootstrap_trees, view, "bootstrap trees", FALSE);
-	  Fl_Window *treew = treedraw(final_tree, view, n ? title:progname, FALSE, tree_count);
-#if !defined(__APPLE__)
+#if !defined(FLTK_COCOA_PLATFORM)
+          Fl_Window *treew =
+#endif
+	  treedraw(final_tree, view, n ? title:progname, FALSE, tree_count);
+#if !defined(FLTK_COCOA_PLATFORM)
       if (btreew) treew->position(btreew->x() + 30, btreew->y() + 40);
 #endif
 	  delete[] title;
@@ -2338,7 +2366,8 @@ char *parsimony_with_jumble(char **pars_seqs, char **pars_names, int n_otu, int
 		for (i = 0; i < br_count; i++) free(rows[i]);
 		free(rows);
     char *newtree = (char*)malloc(strlen(consensus_tree) + strlen(tree) + 2);
-    sprintf(newtree, "%s\n%s", consensus_tree, tree);
+    snprintf(newtree, strlen(consensus_tree) + strlen(tree) + 2, "%s\n%s",
+             consensus_tree, tree);
     free(consensus_tree);
     free(tree);
     tree = newtree;
@@ -2376,7 +2405,7 @@ static char *parsimony_with_bootstrap(allseq *tmpallseqs, char **pars_seqs, char
 	for(j = 0; j < replicates; j++) {
 		if (w_count) {
 		  char tmp[30];
-		  sprintf(tmp, "Bootstrap replicate: %d", j + 1); 
+		  snprintf(tmp, 30, "Bootstrap replicate: %d", j + 1);
 		  w_count->label(tmp);
 		}
 		if (tree_build_interrupted) break;
@@ -2405,7 +2434,7 @@ static char *parsimony_with_bootstrap(allseq *tmpallseqs, char **pars_seqs, char
           q = tmpc + (q - bootstrap_trees);
           bootstrap_trees = tmpc;
         }
-        sprintf(q, "[%.2f]", 1./repl_count); q += strlen(q); // indicate tree weight
+        snprintf(q, 20, "[%.2f]", 1./repl_count); q += strlen(q); // indicate tree weight
         memcpy(q, newtree, l); q += l; // (...) part of tree
         memcpy(q, ";\n", 3); q += 2; // end of tree
       }
@@ -2495,7 +2524,7 @@ char *parsimony(char** seq, char** seqname, int notu, int njumbles, int *steps,
         if (jumble_no > pre_jumble_no && jumble_no < njumbles && w_count) {
           pre_jumble_no = jumble_no;
           char tmp[40];
-          sprintf(tmp, "Jumble attempt: %d steps: %d", jumble_no + 1, *args->steps);
+          snprintf(tmp, 40, "Jumble attempt: %d steps: %d", jumble_no + 1, *args->steps);
           w_count->label(tmp);
         }
       }
@@ -2728,7 +2757,7 @@ char *replace_tree_names_by_rank(const char *tree, char **names, int notu)
 			}
 			else {
 				c = *(q - 1);
-				sprintf(qstart, "Seq%d_", i);
+				snprintf(qstart, 15, "Seq%d_", i);
 				q = qstart + strlen(qstart);
 				*q++ = c;
 				}
