@@ -392,7 +392,7 @@ void draw_tree(FD_unrooted *ob)
 	int char_width, char_height, num, dernier, encore = FALSE, ascend, descend;
 	hit result;
 	hits_field hits;
-#if !(defined(__APPLE__) || defined(WIN32))
+#if !(defined(FLTK_COCOA_PLATFORM) || defined(_WIN32))
         if (fl_display && Fl::event() != FL_DRAG) {
           ob->unrooted_plot->window()->cursor(FL_CURSOR_WAIT);
           Fl::flush();
@@ -430,7 +430,7 @@ void draw_tree(FD_unrooted *ob)
 				  descend, ascend);
 	}
 	if(ob->has_br_length) draw_scale(ob, char_height, ascend);
-#if !(defined(__APPLE__) || defined(WIN32))
+#if !(defined(FLTK_COCOA_PLATFORM) || defined(_WIN32))
         if (fl_display && Fl::event() != FL_DRAG) ob->unrooted_plot->window()->cursor(FL_CURSOR_DEFAULT);
 #endif
 }
@@ -455,7 +455,7 @@ void print_unrooted(FD_unrooted *fd_unrooted, const char *name, bool to_ps_file,
     myprinter = new Fl_Printer();
     if (myprinter->start_job(1, &from, &to) ) return;
   }
-#ifndef NO_PDF
+#if !defined(NO_PDF) && 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION < 140
   jmp_buf *jbuf;
   if (to_ps_file) ((Fl_PDF_File_Device*)myprinter)->surface_try(&jbuf);
   if ( (!to_ps_file) || setjmp(*jbuf) == 0) { // replaces PDF_TRY
@@ -471,7 +471,7 @@ void print_unrooted(FD_unrooted *fd_unrooted, const char *name, bool to_ps_file,
     time_t heure;
     time(&heure);
     char bigline[200];
-    sprintf(bigline, "%s  %s", extract_filename(name), ctime(&heure));
+    snprintf(bigline, 200, "%s  %s", extract_filename(name), ctime(&heure));
     fl_font(FL_TIMES, 12);
     fl_color(FL_BLACK);
     fl_draw(bigline, fd_unrooted->x, fd_unrooted->y - 5);
@@ -482,7 +482,7 @@ void print_unrooted(FD_unrooted *fd_unrooted, const char *name, bool to_ps_file,
     frame_and_draw_unrooted(fd_unrooted);
     myprinter->end_page();
     myprinter->end_job();
-#ifndef NO_PDF
+#if !defined(NO_PDF) && 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION  < 140
     } // end of PDF_TRY
     if (to_ps_file && ((Fl_PDF_File_Device*)myprinter)->surface_catch()) { // replaces PDF_CATCH
       ((Fl_PDF_File_Device*)myprinter)->error_catch();
@@ -602,8 +602,9 @@ if(br->nom != NULL) {
         angle = atan( (-h) / w );
         if( w < 0 ) angle = M_PI + angle;
         if(angle < 0) angle += 2*M_PI;
-		if(angle > M_PI_2 && angle < 3 * M_PI_2) sprintf(txt,"%s ", br->nom);
-		else sprintf(txt, " %s", br->nom);
+		if(angle > M_PI_2 && angle < 3 * M_PI_2) snprintf(txt, 300,
+                                                                  "%s ", br->nom);
+		else snprintf(txt, 300, " %s", br->nom);
 		result = draw_name_angle(&phys_fin, txt, fd_unrooted, angle, doit, 
 								 char_width, char_height, descend, br->color, ascent);
         if( result != NO_HIT ) return result;
@@ -695,7 +696,7 @@ xf = (int)(fd_unrooted->w * 0.97) + fd_unrooted->x_offset;
 xd = xf - phys_w;
 fl_line_style(FL_SOLID, 0, 0);
 fl_line(xd , y, xf, y);
-sprintf(ech_name, "%.1g", log_val);
+snprintf(ech_name, 20, "%.1g", log_val);
 my_draw_text(FL_ALIGN_CENTER, (xd + xf)/2, y - charheight/3, 12, FL_TIMES, ech_name);
 fl_line(xd, y - charheight/3, xd, y + charheight/3);
 fl_line(xf + fd_unrooted->x, y - charheight/3, xf, y + charheight/3);
