@@ -3,8 +3,8 @@
 #include "svg.h"
 #include <ctype.h>
 #include <time.h>
-#ifndef WIN32
-#include <unistd.h>
+#ifndef _WIN32
+#  include <unistd.h>
 #endif
 
 /* included functions */
@@ -95,7 +95,7 @@ extern void allonge_seqs(char **seq, int totseqs, int maxlen, int *eachlength,
 			 int tot_comment_lines, char **comment_line, char **pregion_line);
 extern int int_res_value(const char *name, int def_value);
 extern const char *progname;
-#if defined(__APPLE__)
+#if defined(FLTK_COCOA_PLATFORM)
 extern const char *MG_GetBundleResourcesDir(void);
 #else
 extern char *get_prog_dir(void); 
@@ -141,7 +141,7 @@ char **seq, **seqname, **comments;
 *ret_message = 0;
 *err_message = ret_message;
 if( (masef=fopen(masefname,"r")) == NULL) {
-	sprintf(ret_message,"File not found:%s",masefname);
+	snprintf(ret_message, sizeof(ret_message),"File not found:%s",masefname);
 	return 0;
 	}
 want_header = (pheader != NULL);
@@ -255,7 +255,7 @@ if(want_header) *pheader = header;
 if(provseq != NULL) free(provseq);
 return totseqs+1;
 nomem:
-sprintf(ret_message,"Error: Not enough memory!");
+snprintf(ret_message, sizeof(ret_message),"Error: Not enough memory!");
 totseqs = -1;
 goto fini;
 }
@@ -363,7 +363,7 @@ char **seq, **seqname, **comments, *tmpseq = NULL;
 *ret_message = 0;
 *err_message = ret_message;
 if( (in=fopen(fname,"r")) == NULL) {
-	sprintf(ret_message,"File not found:%s", fname);
+	snprintf(ret_message, sizeof(ret_message),"File not found:%s", fname);
 	return 0;
 	}
 
@@ -453,7 +453,7 @@ if(tmpseq != NULL) free(tmpseq);
 *pheader = NULL;
 return totseqs+1;
 nomem:
-sprintf(ret_message,"Error: Not enough memory!");
+snprintf(ret_message, sizeof(ret_message),"Error: Not enough memory!");
 totseqs = -1;
 goto fini;
 }
@@ -473,12 +473,12 @@ static char ret_message[200];
 *err_message = ret_message;
 in=fopen(fname,"r");
 if(in==NULL) {
-	sprintf(ret_message,"File not found:%s",fname);
+	snprintf(ret_message, sizeof(ret_message),"File not found:%s",fname);
 	return 0;
 	}
 fgets(line,sizeof(line),in);
 if( sscanf(line, "%d%d", &totseqs, &lenseqs) != 2) {
-		sprintf(ret_message,"Not a PHYLIP file");
+		snprintf(ret_message, sizeof(ret_message),"Not a PHYLIP file");
 		totseqs = 0;
 		goto fini;
 		}
@@ -545,11 +545,11 @@ fclose(in);
 *pseq = seq; *pseqname = seqname; *pcomments = comments;
 return totseqs;
 nomem:
-	sprintf(ret_message,"Not enough memory!");
+	snprintf(ret_message, sizeof(ret_message),"Not enough memory!");
 	totseqs = 0;
 	goto fini;
 badfile:
-	sprintf(ret_message,"Bad file format");
+	snprintf(ret_message, sizeof(ret_message),"Bad file format");
 	totseqs = 0;
 	goto fini;
 }
@@ -569,7 +569,7 @@ char **seq, **comments, **seqname = NULL;
 *err_message = ret_message;
 in=fopen(fname,"r");
 if(in==NULL) {
-	sprintf(ret_message,"File not found:%s",fname);
+	snprintf(ret_message, sizeof(ret_message),"File not found:%s",fname);
 	return 0;
 	}
 fgets(line,sizeof(line),in);
@@ -659,7 +659,7 @@ fini:
 fclose(in);
 return tot_spec + 1;
 nomem:
-sprintf(ret_message,"Error: Not enough memory!");
+snprintf(ret_message, sizeof(ret_message),"Error: Not enough memory!");
 tot_spec = -1;
 goto fini;
 }
@@ -678,7 +678,7 @@ char **seq, **seqname, **comments;
 *err_message = ret_message;
 in=fopen(fname,"r");
 if(in==NULL) {
-	sprintf(ret_message,"File not found:%s",fname);
+	snprintf(ret_message, sizeof(ret_message),"File not found:%s",fname);
 	return 0;
 	}
 
@@ -751,7 +751,7 @@ fini:
 fclose(in);
 return tot_spec + 1;
 nomem:
-sprintf(ret_message,"Error: Not enough memory!");
+snprintf(ret_message, sizeof(ret_message),"Error: Not enough memory!");
 tot_spec = -1;
 goto fini;
 }
@@ -951,7 +951,7 @@ do	{
 			fputs(line,out); putc('\n',out);
 			strcpy(line,";;"); l_line=2;
 			}
-		sprintf(line+l_line," %d,%d", segment->debut, segment->fin);
+		snprintf(line+l_line, sizeof(line)-l_line," %d,%d", segment->debut, segment->fin);
 		l_line += strlen(line+l_line);
 		segment= segment->next;
 		}
@@ -1082,7 +1082,7 @@ int save_fasta_file(const char *fname, char **seq, char **comments,
 /* sauver des sequences ou des regions au format fasta
 region_used pointe vers la liste des regions a sauver
 si region_used == NULL, toutes les sequences sont sauvees
-si pad_to_max_length == TRUE && region_used == NULL, les seqs sont allonges a leur longueur max
+si pad_to_max_length == TRUE && region_used == NULL, les seqs sont allongées a leur longueur max
 rend 0 si ok, 1 si erreur d'ecriture dans le fichier
 	2 si tentative de depasser la longueur d'une sequence
 */
@@ -1397,7 +1397,7 @@ else if(format == FASTA_FORMAT)
 if(err == 0)
 	return NULL;
 else if(err == 1) 
-	sprintf(err_message,"Error while writing to file %s",fname);
+	snprintf(err_message, sizeof(err_message),"Error while writing to file %s",fname);
 else if(err == 2) 
 	strcpy(err_message,
 		"Error: region goes beyond the end of one sequence");
@@ -1405,7 +1405,7 @@ return err_message;
 }
 
 
-#if !(defined(WIN32) || defined(__APPLE__))
+#if !(defined(_WIN32) || defined(FLTK_COCOA_PLATFORM))
 static char seaview_prog_dir[200] = "";
 void inform_prog_dir(const char *arg0)
 {
@@ -1431,7 +1431,7 @@ returns NULL if not found
 */
 {
 #define Mxdir 600
-#ifdef WIN32
+#ifdef _WIN32
 #define PATH_SEPAR ';'
 #define DIR_SEPAR '\\'
 #else
@@ -1448,8 +1448,8 @@ if(strchr(fname, DIR_SEPAR) != NULL) {// if fname is a pathname
 	fich = fopen(dir, "r"); /* try first explicit filename */
 	goto way_out; // and don't search more
 	}
-#if defined(__APPLE__)
-sprintf(dir, "%s/%s", MG_GetBundleResourcesDir(), fname);
+#if defined(FLTK_COCOA_PLATFORM)
+snprintf(dir, sizeof(dir), "%s/%s", MG_GetBundleResourcesDir(), fname);
 fich = fopen(dir, "r");
 if(fich != NULL) goto way_out;
 #else
@@ -1487,14 +1487,15 @@ while (fin != NULL);
 way_out:
 	if(fich == NULL) return NULL;
 	fclose(fich);
-#ifndef WIN32
+#ifndef _WIN32
 	if(*dir != '/') {
 		if(strncmp(dir, "./", 2) == 0) memmove(dir, dir + 2, strlen(dir) - 1);
 		char *p, *q;
 		char *cdir = (char *)malloc(PATH_MAX);
 		p = getcwd(cdir, PATH_MAX);
-		q = (char *)malloc(strlen(p) + 1 + strlen(dir) + 1);
-		sprintf(q, "%s/%s", p, dir);
+                int lq = strlen(p) + 1 + strlen(dir) + 1;
+		q = (char *)malloc(lq);
+		snprintf(q, lq, "%s/%s", p, dir);
 		strcpy(dir, q);
 		free(q); 
 		free(cdir);
@@ -1637,9 +1638,10 @@ chooser->directory(extract_dirname(fname));
 chooser->preset_file(extract_filename(fname)); 
 	
 p = types_list;
+int lp = sizeof(types_list);
 for(int f = 0; f < nbr_formats; f++) {
-	sprintf(p, "%s\t*.%s\n", f_format_names[f], f_format_exts[f]);
-	p += strlen(p);
+	snprintf(p, lp, "%s\t*.%s\n", f_format_names[f], f_format_exts[f]);
+        lp -= strlen(p); p += strlen(p);
 	}
 chooser->filter(types_list);    
 chooser->filter_value(view->format_for_save);    
@@ -1655,7 +1657,7 @@ const char *extract_dirname(const char *pathname)
 	static char dirname[300];
 	char *p;
 	
-#if defined(WIN32)
+#if defined(_WIN32)
 	p = strrchr(pathname,'\\'); 
 #else
 	p = (char*)strrchr(pathname,'/'); 
@@ -1681,7 +1683,7 @@ int printout(SEA_VIEW *view, const char *filename,
   static char num_line[200];
   int lettre, char_per_line;
   short *vary_need = NULL;
-  int *vary_pos; /* rang ds alignement de la colonne imprime */
+  int *vary_pos; /* rang ds alignement de la colonne imprimée */
   char *p, oneline[500];
   int (*calc_color_function)(int);
   double	char_width = fontsize/2, descender, margin = 25;
@@ -1706,7 +1708,7 @@ int printout(SEA_VIEW *view, const char *filename,
   else if(use_svg) {
     FILE *out = fl_fopen(filename, "w");
     if (out == NULL) exit(1);
-#ifndef NO_PDF
+#if !defined(NO_PDF) && 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION  < 140
     SVG_PDF_width_Graphics_Driver *pdf_d = new SVG_PDF_width_Graphics_Driver(NULL);
     pdf_d->font(FL_COURIER, fontsize);
     char_width = pdf_d->width("X", 1);
@@ -1730,13 +1732,14 @@ int printout(SEA_VIEW *view, const char *filename,
     textfile = fopen(filename, "w");
     if(textfile == NULL) return TRUE;
   }
-#ifndef NO_PDF
+#if !defined(NO_PDF) &&  100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION  < 140
   jmp_buf* jbuf;
   if (use_pdf) ((PDF_or_PS_File_Device*)surface)->surface_try(&jbuf);
   if ( (!use_pdf) || (setjmp(*jbuf) == 0)) {
 #endif
     if (use_pdf) {
       surface->driver()->font(FL_COURIER, fontsize);
+      fl_font(FL_COURIER, fontsize);
       char_width = fl_width("X");
       int pwidth, pheight;
       ((PDF_or_PS_File_Device*)surface)->printable_rect(&pwidth, &pheight);
@@ -1758,11 +1761,12 @@ int printout(SEA_VIEW *view, const char *filename,
     
     if(ref0 < 0) vary_only = FALSE;
     time(&heure);
-    sprintf(oneline,"Alignment: %s", view->masename == NULL ? unnamed : PREPARE_LABEL(view->masename) );
+    snprintf(oneline, sizeof(oneline),"Alignment: %s", view->masename == NULL ? unnamed : PREPARE_LABEL(view->masename) );
     if (use_pdf) {
       ((PDF_or_PS_File_Device*)surface)->start_page();
       ((PDF_or_PS_File_Device*)surface)->origin(0, fontsize);
-      fl_draw(oneline, margin, top_margin); 
+      fl_color(FL_BLACK);
+      fl_draw(oneline, margin, top_margin);
     }
     else if(!use_svg) {fputs(oneline, textfile); fputs("\n", textfile);}
     curr_lines = 1;
@@ -1773,7 +1777,7 @@ int printout(SEA_VIEW *view, const char *filename,
       ++curr_lines;
     }
     if (use_pdf) {
-      sprintf(oneline,"Seaview [blocks=%d fontsize=%d %s%s] on %s",
+      snprintf(oneline, sizeof(oneline),"Seaview [blocks=%d fontsize=%d %s%s] on %s",
 	    block_size, fontsize, pageformat == Fl_Paged_Device::A4 ? "A4" : "LETTER", 
 	    layout == Fl_Paged_Device::LANDSCAPE ? "-landscape" : "", ctime(&heure));
       p = strchr(oneline, '\n'); if (p) *p = 0;
@@ -1781,7 +1785,7 @@ int printout(SEA_VIEW *view, const char *filename,
       curr_lines += 2;
     }
     else if(use_svg) {
-      sprintf(oneline,"created by Seaview on %s", ctime(&heure));
+      snprintf(oneline, sizeof(oneline),"created by Seaview on %s", ctime(&heure));
       p = strchr(oneline, '\n'); if (p) *p = 0;
       fl_color(FL_BLACK);
       fl_draw(oneline, margin, top_margin + curr_lines * fontsize); 
@@ -1831,6 +1835,7 @@ int printout(SEA_VIEW *view, const char *filename,
 	((PDF_or_PS_File_Device*)surface)->start_page();
 	((PDF_or_PS_File_Device*)surface)->origin(0, fontsize);
 	surface->driver()->font(FL_COURIER, fontsize);
+        fl_color(FL_BLACK);
 	curr_lines = 0;
       }
       if(vary_only) {
@@ -1838,7 +1843,7 @@ int printout(SEA_VIEW *view, const char *filename,
 	curr_lines += nl;
       }
       else	{
-	sprintf(num_line, "%d", current + 1);
+	snprintf(num_line, sizeof(num_line), "%d", current + 1);
 	fin = strlen(num_line);
 	memmove(num_line + widnames - fin + 1, num_line, fin+1);
 	if(fin <= widnames) memset(num_line, ' ', widnames - fin + 1);
@@ -1902,6 +1907,7 @@ int printout(SEA_VIEW *view, const char *filename,
 	  ((PDF_or_PS_File_Device*)surface)->start_page();
 	  ((PDF_or_PS_File_Device*)surface)->origin(0, fontsize);
 	  surface->driver()->font(FL_COURIER, fontsize);
+          fl_color(FL_BLACK);
 	  curr_lines = 0;
 	}
 	if(!use_pdf && !use_svg) {
@@ -1939,7 +1945,7 @@ int printout(SEA_VIEW *view, const char *filename,
       ((SVG_File_Surface*)surface)->end();
       }
     else fclose(textfile);
-#ifndef NO_PDF
+#if !defined(NO_PDF) &&  100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION  < 140
   } /* end of PDF_TRY */
   if (use_pdf && ((PDF_or_PS_File_Device*)surface)->surface_catch()) {
     ((PDF_or_PS_File_Device*)surface)->error_catch();
