@@ -264,11 +264,11 @@ for(num = 0; num < view->tot_seqs; num++)
 gc = get_ncbi_gc_from_comment(view->comments[num]);
 Fl_Hold_Browser *obj = new Fl_Hold_Browser(5, 25, 840, 350);
 obj->textfont(FL_COURIER);
-sprintf(line, "Set genetic code for %s", view->tot_sel_seqs > 1 ? "selected sequences" : view->seqname[num]);
+snprintf(line, sizeof(line), "Set genetic code for %s", view->tot_sel_seqs > 1 ? "selected sequences" : view->seqname[num]);
 obj->copy_label(line);
 obj->align(FL_ALIGN_TOP);
 for(num = 0; num < totcodes; num++) {
-	sprintf(line, "%65.65s|%2d| %s", get_code_target(num), get_ncbi_gc_number(num), get_code_descr(num));
+	snprintf(line, sizeof(line), "%65.65s|%2d| %s", get_code_target(num), get_ncbi_gc_number(num), get_code_descr(num));
 	obj->add(line);
 	}
 obj->value(get_acnuc_gc_number(gc) + 1);
@@ -318,13 +318,13 @@ if(p != NULL) {
 	*(q+1) = 0;
 	p = (char *)malloc(l + 3);
 	if(p == NULL) return;
-	sprintf(p, "%s%d%s", comm, ncbigc, r);
+	snprintf(p, l + 3, "%s%d%s", comm, ncbigc, r);
 	}
 else {
 	p = (char *)malloc(l + 20);
 	if(p == NULL) return;
 	if(l > 2) strcpy(p, comm); else *p = 0;
-	sprintf(p + strlen(p), ";/transl_table=%d\n", ncbigc);
+	snprintf(p + strlen(p), l+20-strlen(p), ";/transl_table=%d\n", ncbigc);
 	}
 if(comm != NULL) free(comm);
 view->comments[seqnum] = p;
