@@ -1,11 +1,11 @@
-#ifdef WIN32
+#ifdef _WIN32
 
 #include <FL/Enumerations.H>
 #include "pdf_or_ps.h"
 #include <FL/fl_utf8.h>
 #include <stdlib.h>
 #include <stdio.h>
-#  ifndef NO_PDF
+#if !defined(NO_PDF) && 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION  < 140
 #    include <pdflib.h>
 #  endif
 
@@ -95,7 +95,7 @@ const char *win32_UTF8_to_CP1252(const char *in)
 }
 
 
-#ifndef NO_PDF
+#if 0 //ndef NO_PDF
 static size_t pdf_write_proc(PDF *p, void *data, size_t size)
 {
   FILE **output = (FILE**)PDF_get_opaque(p);
@@ -250,4 +250,4 @@ void delete_tmp_filename(const char *base_fname)
 
  */
 
-#endif // WIN32
+#endif // _WIN32
