@@ -6,7 +6,7 @@
 #include <string.h>
 #include <ctype.h>
 
-#ifndef NO_PDF
+#if !defined(NO_PDF) && 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION  < 140
 #include <pdflib.h>
 #endif
 
@@ -165,7 +165,7 @@ user_data_plus *data;
 
 fdui->title = def_title;
 
-#if defined(WIN32) || defined(__APPLE__)
+#if defined(_WIN32) || defined(FLTK_COCOA_PLATFORM)
 fontsize = 10;
 fdui->form = form = new Fl_Window(560, 540);
 #else
@@ -209,7 +209,7 @@ Fl_Widget *postscript = cre_button(fin, curr_y, &width, but_height, fontsize, "W
 fin += width;
 postscript->callback(plot_button_proc, fdui);
 
-#ifndef WIN32
+#ifndef _WIN32
 fin += 2;
 Fl_Widget *close = cre_button(fin, curr_y, &width, but_height, fontsize, "Close");
 ((Fl_Button *)close)->shortcut(FL_COMMAND | 'w');
@@ -222,7 +222,7 @@ width = top->x() + top->w() - width;
 width = width - curr_x;
 compute->position(compute->x() + width, compute->y() );
 postscript->position(postscript->x() + width, postscript->y() );
-#ifndef WIN32
+#ifndef _WIN32
 close->position(close->x() + width, close->y() );
 #endif
 
@@ -290,7 +290,7 @@ align_group->end();
 curr_y += but_height + 2;
 Fl_Group *region_group = new Fl_Group(top->x(), curr_y, top->w(), 80);
 
-#ifdef WIN32
+#ifdef _WIN32
 #define SQW 15
 #else
 #define SQW 20
@@ -493,11 +493,11 @@ matpt->plotname = (char *)malloc(strlen(name) + 1);
 strcpy(matpt->plotname, name);
 if(matpt->align_button != NULL) {
 	char temp[200], name1[40], name2[40], *p;
-	sprintf(name1, "%.30s", seqname1);
+	snprintf(name1, 40, "%.30s", seqname1);
 	if((p = strchr(name1,'|')) != NULL) *p = 0;
-	sprintf(name2, "%.30s", seqname2);
+	snprintf(name2, 40, "%.30s", seqname2);
 	if((p = strchr(name2,'|')) != NULL) *p = 0;
-	sprintf(temp, "align to %s|align to %s", name1, name2);
+	snprintf(temp, 200, "align to %s|align to %s", name1, name2);
 	((Fl_Choice*)matpt->choice_ref_seq)->clear();
 	((Fl_Choice *)matpt->choice_ref_seq)->value(0);
 	((Fl_Choice *)matpt->choice_ref_seq)->add(temp);
@@ -526,7 +526,7 @@ static char newtext[sizeof(matpt->regionboxtext)];
 
 if(matpt->longmax == 0) return;
 p = newtext;
-sprintf(p, "%5d ", matpt->hitx);
+snprintf(p, 10, "%5d ", matpt->hitx);
 l = FL_min(matpt->region_size, matpt->seqlong1 - matpt->hitx + 1);
 l = FL_min(l, matpt->seqlong2 - matpt->hity + 1);
 memcpy(p+6, (matpt->seq1 + matpt->hitx), l);
@@ -544,12 +544,12 @@ for(i=0; i < l; i++) {
 	else
 		*(p + i + 6)=' ';
 	}
-sprintf(p,"%d/%d", matches, matpt->region_size);
+snprintf(p, 25, "%d/%d", matches, matpt->region_size);
 *(p + strlen(p)) = ' ';
 *(p + 6 + l)='\n';
 p += l + 7;
 
-sprintf(p, "%5d ", matpt->hity);
+snprintf(p, 10, "%5d ", matpt->hity);
 memcpy(p+6, (matpt->seq2 + matpt->hity), l);
 *(p + l + 6)='\0';
 if(strcmp(matpt->regionboxtext, newtext) != 0) {
@@ -747,7 +747,7 @@ else
 if(fdui->identites > fdui->fenetre && fdui->fenetre>0) {
 	char tmp[10];
 	fdui->identites = fdui->fenetre;
-	sprintf(tmp,"%d", fdui->identites);
+	snprintf(tmp, 10,"%d", fdui->identites);
 	((Fl_Input *)fdui->ident_type_box)->value(tmp);
 	}
 }
@@ -811,7 +811,7 @@ int old_phys;
   PDF_or_PS_File_Device* surface = new PDF_or_PS_File_Device();
   if (surface->start_job(matpt->plotname, printout_pageformat)) return;
 // we use bottom-up coords for PDF and PS output, it's rather tricky.  
-#ifndef NO_PDF
+#if !defined(NO_PDF) && 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION  < 140
 jmp_buf *jbuf;
 surface->surface_try(&jbuf);
 if (setjmp(*jbuf) == 0) {
@@ -845,7 +845,7 @@ if (setjmp(*jbuf) == 0) {
   matpt->phys_width = old_phys;
   reset_mat_data(matpt);
 
-  sprintf(message,
+  snprintf(message, sizeof(message),
 	  "Horizontal: %.30s (%d)  Vertical: %.30s (%d)  Window: %d Matches: %d",
 	  matpt->seqname1, matpt->seqlong1, matpt->seqname2, matpt->seqlong2, 
 		  matpt->fenetre, matpt->identites);
@@ -859,7 +859,7 @@ if (setjmp(*jbuf) == 0) {
   fl_draw(message, 0, 0);
   surface->end_page();
   surface->end_job();
-#ifndef NO_PDF
+#if !defined(NO_PDF) && 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION  < 140
 } /* end of PDF_TRY */
   if( surface->surface_catch() ) {
     surface->error_catch();
@@ -959,7 +959,7 @@ matpt->mat_panel->redraw();
 void compute_title(FD_matpt *matpt)
 {
 static char title[150];
-sprintf(title, "Horizontal: %.30s (%d)   Vertical: %.30s (%d)",
+snprintf(title, 150, "Horizontal: %.30s (%d)   Vertical: %.30s (%d)",
 	matpt->seqname1, matpt->seqlong1, matpt->seqname2, matpt->seqlong2);
 matpt->title = title;
 matpt->mat_panel->window()->label(title);
@@ -1179,7 +1179,7 @@ fl_reset_cursor(ob->window());
 void matpt_idle_cb(FD_matpt *matpt)
 {
   static char err_seg[]="Only part of the dot plot was computed";
-#ifdef __APPLE__
+#ifdef FLTK_COCOA_PLATFORM
   const int step = 100; // on Mac OS, idle callbacks are slow to be called, so better give them more work
 #else
   const int step = 1;
